@@ -1,7 +1,7 @@
 /****************************************************************************
-** $Id: qt/application.cpp   3.3.3   edited Jul 17 2003 $
+** $Id: qt/application.cpp   3.3.6   edited Aug 31 2005 $
 **
-** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of an example program for Qt.  This example
 ** program may be used, distributed and modified without limitation.
@@ -239,23 +239,22 @@ void ApplicationWindow::print()
 	QPaintDeviceMetrics metrics( p.device() );
 	int dpiy = metrics.logicalDpiY();
 	int margin = (int) ( (2/2.54)*dpiy ); // 2 cm margins
-	QRect body( margin, margin, metrics.width() - 2*margin, metrics.height() - 2*margin );
+	QRect view( margin, margin, metrics.width() - 2*margin, metrics.height() - 2*margin );
 	QSimpleRichText richText( QStyleSheet::convertFromPlainText(e->text()),
 				  QFont(),
 				  e->context(),
 				  e->styleSheet(),
 				  e->mimeSourceFactory(),
-				  body.height() );
-	richText.setWidth( &p, body.width() );
-  	QRect view( body );
+				  view.height() );
+	richText.setWidth( &p, view.width() );
 	int page = 1;
 	do {
-	    richText.draw( &p, body.left(), body.top(), view, colorGroup() );
-	    view.moveBy( 0, body.height() );
-	    p.translate( 0 , -body.height() );
+	    richText.draw( &p, margin, margin, view, colorGroup() );
+	    view.moveBy( 0, view.height() );
+	    p.translate( 0 , -view.height() );
 	    p.drawText( view.right() - p.fontMetrics().width( QString::number( page ) ),
 			view.bottom() + p.fontMetrics().ascent() + 5, QString::number( page ) );
-	    if ( view.top()  >= richText.height() )
+	    if ( view.top() - margin >= richText.height() )
 		break;
 	    printer->newPage();
 	    page++;
