@@ -1,7 +1,7 @@
 /****************************************************************************
-** $Id: qt/tagreader.cpp   3.3.3   edited May 27 2003 $
+** $Id: qt/tagreader.cpp   3.3.6   edited Feb 20 14:08 $
 **
-** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of an example program for Qt.  This example
 ** program may be used, distributed and modified without limitation.
@@ -16,15 +16,15 @@
 int main( int argc, char **argv )
 {
     if ( argc < 2 ) {
-	fprintf( stderr, "Usage: %s <xmlfile>\n", argv[0] );
+	fprintf( stderr, "Usage: %s <xmlfile> [<xmlfile> ...]\n", argv[0] );
 	return 1;
     }
+    StructureParser handler;
+    QXmlSimpleReader reader;
+    reader.setContentHandler( &handler );
     for ( int i=1; i < argc; i++ ) {
-        StructureParser handler;
         QFile xmlFile( argv[i] );
         QXmlInputSource source( &xmlFile );
-        QXmlSimpleReader reader;
-        reader.setContentHandler( &handler );
         reader.parse( source );
     }
     return 0;
