@@ -1,9 +1,9 @@
 /****************************************************************************
-** $Id: qt/qdragobject.h   3.3.3   edited May 27 2003 $
+** $Id: qt/qdragobject.h   3.3.6   edited Jan 30 09:42 $
 **
 ** Definition of QDragObject
 **
-** Copyright (C) 1992-2002 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the kernel module of the Qt GUI Toolkit.
 **
@@ -250,6 +250,9 @@ private:
     QDragObject * object;
     void updateMode( ButtonState newstate );
     void updateCursor();
+#if defined(Q_WS_X11)
+    void createCursors();
+#endif
 
     QWidget * dragSource;
     QWidget * dropWidget;
