@@ -1,11 +1,11 @@
 /****************************************************************************
-** $Id: qt/qstring.h   3.3.3   edited Mar 31 13:28 $
+** $Id: qt/qstring.h   3.3.6   edited Aug 31 2005 $
 **
 ** Definition of the QString class, and related Unicode functions.
 **
 ** Created : 920609
 **
-** Copyright (C) 1992-2002 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the tools module of the Qt GUI Toolkit.
 **
@@ -47,7 +47,7 @@
 #endif
 
 #ifndef QT_NO_STL
-#if defined ( Q_CC_MSVC_NET ) && _MSV_VER < 1310 // Avoids nasty warning for xlocale, line 450
+#if defined ( Q_CC_MSVC_NET ) && _MSC_VER < 1310 // Avoids nasty warning for xlocale, line 450
 #  pragma warning ( push )
 #  pragma warning ( disable : 4189 )
 #  include <string>
@@ -531,7 +531,7 @@ public:
     QString    &append( const QByteArray & );
     QString    &append( const char * );
 #endif
-#ifndef QT_NO_STL
+#if !defined(QT_NO_STL) && !defined(QT_NO_CAST_ASCII)
     QString    &append( const std::string& );
 #endif
     QString    &prepend( char );
@@ -541,7 +541,7 @@ public:
     QString    &prepend( const QByteArray & );
     QString    &prepend( const char * );
 #endif
-#ifndef QT_NO_STL
+#if !defined(QT_NO_STL) && !defined(QT_NO_CAST_ASCII)
     QString    &prepend( const std::string& );
 #endif
     QString    &remove( uint index, uint len );
@@ -628,7 +628,7 @@ public:
     QString    &operator+=( const QByteArray &str );
     QString    &operator+=( const char *str );
 #endif
-#ifndef QT_NO_STL
+#if !defined(QT_NO_STL) && !defined(QT_NO_CAST_ASCII)
     QString    &operator+=( const std::string& );
 #endif
     QString    &operator+=( QChar c );
@@ -941,6 +941,7 @@ inline QString &QString::append( char c )
 #ifndef QT_NO_STL
 inline QString &QString::operator=( const std::string& str )
 { return operator=(str.c_str()); }
+#ifndef QT_NO_CAST_ASCII
 inline QString &QString::operator+=( const std::string& s )
 { return operator+=(s.c_str()); }
 inline QString &QString::append( const std::string& s )
@@ -948,6 +949,7 @@ inline QString &QString::append( const std::string& s )
 inline QString &QString::prepend( const std::string& s )
 { return insert(0, s); }
 #endif
+#endif
 
 inline QString &QString::setNum( short n, int base )
 { return setNum((Q_LLONG)n, base); }
