@@ -1,11 +1,11 @@
 /****************************************************************************
-** $Id:  qt/qstyle.h   3.0.5   edited May 7 22:37 $
+** $Id: qt/qstyle.h   3.3.6   edited Aug 31 2005 $
 **
 ** Definition of QStyle class
 **
 ** Created : 980616
 **
-** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the kernel module of the Qt GUI Toolkit.
 **
@@ -49,6 +49,7 @@ class QStylePrivate;
 class QMenuItem;
 class QTab;
 class QListViewItem;
+class QCheckListItem;
 
 class QStyleOption {
 public:
@@ -58,6 +59,8 @@ public:
 
     // Note: we don't use default arguments since that is unnecessary
     // initialization.
+    QStyleOption(int in1) :
+	def(FALSE), i1(in1) {}
     QStyleOption(int in1, int in2) :
 	def(FALSE), i1(in1), i2(in2) {}
     QStyleOption(int in1, int in2, int in3, int in4) :
@@ -68,15 +71,21 @@ public:
     QStyleOption(const QColor& c) : def(FALSE), cl(&c) {}
     QStyleOption(QTab* t) : def(FALSE), tb(t) {}
     QStyleOption(QListViewItem* i) : def(FALSE), li(i) {}
+    QStyleOption(QCheckListItem* i) : def(FALSE), cli(i) {}
     QStyleOption(Qt::ArrowType a) : def(FALSE), i1((int)a) {}
+    QStyleOption(const QRect& r) : def(FALSE), i1(r.x()), i2(r.y()), i3(r.width()),i4(r.height()){}
+    QStyleOption(QWidget *w) : def(FALSE), p1((void*)w) {}
 
     bool isDefault() const { return def; }
 
+    int day() const { return i1; }
+
     int lineWidth() const { return i1; }
     int midLineWidth() const { return i2; }
     int frameShape() const { return i3; }
     int frameShadow() const { return i4; }
 
+    int headerSection() const { return i1; }
     QMenuItem* menuItem() const { return mi; }
     int maxIconWidth() const { return i1; }
     int tabWidth() const { return i2; }
@@ -85,9 +94,12 @@ public:
 
     QTab* tab() const { return tb; }
 
+    QCheckListItem* checkListItem() const { return cli; }
     QListViewItem* listViewItem() const { return li; }
 
     Qt::ArrowType arrowType() const { return (Qt::ArrowType)i1; }
+    QRect rect() const { return QRect( i1, i2, i3, i4 ); }
+    QWidget* widget() const { return (QWidget*)p1; }
 
 private:
     // NOTE: none of these components have constructors.
@@ -99,7 +111,8 @@ private:
     const QColor* cl;
     int i1, i2, i3, i4;
     int i5, i6; // reserved
-    void *p1, *p2, *p3, *p4, *p5; // reserved
+    QCheckListItem* cli;
+    void *p1, *p2, *p3, *p4; // reserved
     // (padded to 64 bytes on some architectures)
 };
 
@@ -200,6 +213,13 @@ public:
 
 	PE_WindowFrame,
 
+	PE_CheckListController,
+	PE_CheckListIndicator,
+	PE_CheckListExclusiveIndicator,
+
+	PE_PanelGroupBox,
+	PE_RubberBand,
+
 	// do not add any values below/greater this
 	PE_CustomBase =			0xf000000
     };
@@ -256,7 +276,14 @@ public:
 	CE_MenuBarItem,
 
 	CE_ToolButtonLabel,
+	CE_MenuBarEmptyArea,
 	CE_PopupMenuScroller,
+	CE_DockWindowEmptyArea,
+	CE_PopupMenuVerticalExtra,
+	CE_PopupMenuHorizontalExtra,
+
+	CE_ToolBoxTab,
+	CE_HeaderLabel,
 
 	// do not add any values below/greater than this
 	CE_CustomBase =		0xf0000000
@@ -299,6 +326,18 @@ public:
 
 	SR_ToolButtonContents,
 
+	SR_DialogButtonAccept,
+	SR_DialogButtonReject,
+	SR_DialogButtonApply,
+	SR_DialogButtonHelp,
+	SR_DialogButtonAll,
+	SR_DialogButtonAbort,
+	SR_DialogButtonIgnore,
+	SR_DialogButtonRetry,
+	SR_DialogButtonCustom,
+
+	SR_ToolBoxTabContents,
+
 	// do not add any values below/greater than this
 	SR_CustomBase =		0xf0000000
     };
@@ -340,6 +379,7 @@ public:
 	SC_ComboBoxFrame =		0x00000001,
 	SC_ComboBoxEditField =		0x00000002,
 	SC_ComboBoxArrow =		0x00000004,
+	SC_ComboBoxListBoxPopup =	0x00000008,
 
 	SC_SliderGroove =		0x00000001,
 	SC_SliderHandle = 		0x00000002,
@@ -372,7 +412,11 @@ public:
 				     const QRect &r,
 				     const QColorGroup &cg,
 				     SFlags how = Style_Default,
+#ifdef Q_QDOC
 				     SCFlags sub = SC_All,
+#else
+				     SCFlags sub = (uint)SC_All,
+#endif
 				     SCFlags subActive = SC_None,
 				     const QStyleOption& = QStyleOption::Default ) const = 0;
     virtual void drawComplexControlMask( ComplexControl control,
@@ -434,6 +478,26 @@ public:
 	PM_ExclusiveIndicatorWidth,
 	PM_ExclusiveIndicatorHeight,
 	PM_PopupMenuScrollerHeight,
+	PM_CheckListButtonSize,
+	PM_CheckListControllerSize,
+	PM_PopupMenuFrameHorizontalExtra,
+	PM_PopupMenuFrameVerticalExtra,
+
+	PM_DialogButtonsSeparator,
+	PM_DialogButtonsButtonWidth,
+	PM_DialogButtonsButtonHeight,
+
+	PM_MDIFrameWidth,
+	PM_MDIMinimizedWidth,
+	PM_HeaderMargin,
+	PM_HeaderMarkSize,
+	PM_HeaderGripMargin,
+	PM_TabBarTabShiftHorizontal,
+	PM_TabBarTabShiftVertical,
+	PM_TabBarScrollButtonWidth,
+
+	PM_MenuBarItemSpacing,
+	PM_ToolBarItemSpacing,
 
 	// do not add any values below/greater than this
 	PM_CustomBase =		0xf0000000
@@ -453,6 +517,15 @@ public:
 	CT_DockWindow,
 	CT_ProgressBar,
 	CT_PopupMenuItem,
+	CT_TabBarTab,
+	CT_Slider,
+	CT_Header,
+	CT_LineEdit,
+	CT_MenuBar,
+	CT_SpinBox,
+	CT_SizeGrip,
+	CT_TabWidget,
+	CT_DialogButtons,
 
 	// do not add any values below/greater than this
 	CT_CustomBase =		0xf0000000
@@ -550,7 +623,7 @@ public:
 	SH_Workspace_FillSpaceOnMaximize,
 
 	// bool - supports popup menu comboboxes
-	SH_ComboBox_Popup, 
+	SH_ComboBox_Popup,
 
 	// bool - titlebar has no border
 	SH_TitleBar_NoBorder,
@@ -567,6 +640,44 @@ public:
 	//bool - popupmenu supports scrolling instead of multicolumn mode
 	SH_PopupMenu_Scrollable,
 
+	// Qt::AlignmentFlags - text label vertical alignment in groupboxes
+	// Center on windows, Auto|VCenter otherwize
+	SH_GroupBox_TextLabelVerticalAlignment,
+
+	// Qt::QRgb - text label color in groupboxes
+	SH_GroupBox_TextLabelColor,
+
+	// bool - popupmenu supports sloppy submenus
+	SH_PopupMenu_SloppySubMenus,
+
+	// Qt::QRgb - table grid color
+	SH_Table_GridLineColor,
+
+	// QChar - Unicode character for password char
+	SH_LineEdit_PasswordCharacter,
+
+	// QDialogButtons::Button - default button
+	SH_DialogButtons_DefaultButton,
+
+	// QToolBox - Boldness of the selected page title
+	SH_ToolBox_SelectedPageTitleBold,
+
+	//bool - if a tabbar prefers not to have scroller arrows
+	SH_TabBar_PreferNoArrows,
+
+	//bool - if left button should cause an absolute position
+	SH_ScrollBar_LeftClickAbsolutePosition,
+
+	// QEvent::Type - which mouse event to select a list view expansion
+	SH_ListViewExpand_SelectMouseType,
+
+	//bool - if underline for accelerators
+	SH_UnderlineAccelerator,
+
+	// bool - QToolButton - if tool buttons should use a 3D frame
+	// when the mouse is over the button
+	SH_ToolButton_Uses3D,
+
 	// do not add any values below/greater than this
 	SH_CustomBase =		0xf0000000
     };
@@ -589,6 +700,7 @@ public:
 	SP_MessageBoxInformation,
 	SP_MessageBoxWarning,
 	SP_MessageBoxCritical,
+	SP_MessageBoxQuestion,
 
 	// do not add any values below/greater than this
 	SP_CustomBase =		0xf0000000
