@@ -4,7 +4,7 @@
 **
 ** Created : 000607
 **
-** Copyright (C) 1992-2002 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the table module of the Qt GUI Toolkit.
 **
@@ -161,10 +161,6 @@ public:
     virtual int rtti() const;
     static int RTTI;
 
-protected:
-    // ### Make virtual in 4.0
-    QString content() const;
-
 private:
     QString txt;
     QPixmap pix;
@@ -187,6 +183,7 @@ class QM_EXPORT_TABLE QComboTableItem : public QTableItem
 {
 public:
     QComboTableItem( QTable *table, const QStringList &list, bool editable = FALSE );
+    ~QComboTableItem();
     virtual QWidget *createEditor() const;
     virtual void setContentFromEditor( QWidget *w );
     virtual void paint( QPainter *p, const QColorGroup &cg,
@@ -215,6 +212,8 @@ private:
     int current;
     bool edit;
     static QComboBox *fakeCombo;
+    static QWidget *fakeComboWidget;
+    static int fakeRef;
 
 };
 
@@ -361,6 +360,8 @@ public slots:
     virtual void hideColumn( int col );
     virtual void showRow( int row );
     virtual void showColumn( int col );
+    bool isRowHidden( int row ) const;
+    bool isColumnHidden( int col ) const;
 
     virtual void setColumnWidth( int col, int w );
     virtual void setRowHeight( int row, int h );
@@ -492,7 +493,7 @@ private:
     void updateRowWidgets( int row );
     void updateColWidgets( int col );
     bool isSelected( int row, int col, bool includeCurrent ) const;
-    void setCurrentCell( int row, int col, bool updateSelections );
+    void setCurrentCell( int row, int col, bool updateSelections, bool ensureVisible = FALSE );
     void fixCell( int &row, int &col, int key );
     void delayedUpdateGeometries();
     struct TableWidget
@@ -527,7 +528,7 @@ private:
     bool mCols : 1;
     bool asc : 1;
     bool doSort : 1;
-    bool mousePressed : 1;
+    bool unused : 1;
     bool readOnly : 1;
     bool shouldClearSelection : 1;
     bool dEnabled : 1;
