@@ -1,11 +1,11 @@
 /****************************************************************************
-** $Id: qt/qtextedit.h   3.3.4   edited Jan 12 2004 $
+** $Id: qt/qtextedit.h   3.3.6   edited Aug 31 2005 $
 **
 ** Definition of the QTextEdit class
 **
 ** Created : 990101
 **
-** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the widgets module of the Qt GUI Toolkit.
 **
@@ -468,7 +468,7 @@ private slots:
 
 private:
     struct Q_EXPORT UndoRedoInfo {
-	enum Type { Invalid, Insert, Delete, Backspace, Return, RemoveSelected, Format, Style };
+	enum Type { Invalid, Insert, Delete, Backspace, Return, RemoveSelected, Format, Style, IME };
 
 	UndoRedoInfo( QTextDocument *dc );
 	~UndoRedoInfo();
