@@ -1,9 +1,9 @@
 /****************************************************************************
-** $Id: qt/unixmake2.cpp   3.3.2   edited Mar 31 10:36 $
+** $Id: qt/unixmake2.cpp   3.3.6   edited Aug 31 2005 $
 **
 ** Implementation of UnixMakefileGenerator class.
 **
-** Copyright (C) 1992-2003 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of qmake.
 **
@@ -728,10 +728,11 @@ UnixMakefileGenerator::writeMakeParts(QTextStream &t)
 	  << ",g\" \"" << info_plist << "\" >\"" << info_plist_out << "\"" << endl;
 	if(!project->first("RC_FILE").isEmpty()) {
 	    QString dir = destdir + "../Resources/";
-	    t << dir << "application.icns: " << var("RC_FILE") << "\n\t"
+	    t << dir << "application.icns: " << fileFixify(var("RC_FILE")) << "\n\t"
 	      << "@test -d " << dir << " || mkdir -p " << dir << "\n\t"
 	      << "@$(DEL_FILE) " << dir << "application.icns" << "\n\t"
-	      << "@$(COPY_FILE) " << var("RC_FILE") << " " << dir << "application.icns" << endl;
+	      << "@$(COPY_FILE) " << fileFixify(var("RC_FILE"))
+              << " " << dir << "application.icns" << endl;
 	}
     }
 
@@ -842,7 +843,7 @@ UnixMakefileGenerator::writeMakeParts(QTextStream &t)
     if(doPrecompiledHeaders() && !project->isEmpty("PRECOMPILED_HEADER")) {
 	QString header_prefix = project->first("QMAKE_PRECOMP_PREFIX");
 	QString precomph_out_dir = project->first("QMAKE_ORIG_TARGET") + ".gch" + Option::dir_sep;
-	t << "-$(DEL_FILE) " << precomph_out_dir << header_prefix + "c "
+	t << "-$(DEL_FILE) " << precomph_out_dir << (header_prefix + "c ")
 	  << precomph_out_dir << header_prefix << "c++" << "\n\t";
     }
     if(!project->isEmpty("IMAGES"))
@@ -954,16 +955,16 @@ UnixMakefileGenerator::writeMakeParts(QTextStream &t)
 		QString in = Option::fixPathToTargetOS((*input), FALSE),
 		       out = tmp_out, cmd = tmp_cmd, deps;
 		out.replace("${QMAKE_FILE_BASE}", fi.baseName());
-		out.replace("${QMAKE_FILE_NAME}", fi.fileName());
+		out.replace("${QMAKE_FILE_NAME}", fi.filePath());
 		cmd.replace("${QMAKE_FILE_BASE}", fi.baseName());
 		cmd.replace("${QMAKE_FILE_OUT}", out);
-		cmd.replace("${QMAKE_FILE_NAME}", fi.fileName());
+		cmd.replace("${QMAKE_FILE_NAME}", fi.filePath());
 		for(QStringList::Iterator it3 = vars.begin(); it3 != vars.end(); ++it3)
 		    cmd.replace("$(" + (*it3) + ")", "$(QMAKE_COMP_" + (*it3)+")");
 		if(!tmp_dep.isEmpty()) {
 		    char buff[256];
 		    QString dep_cmd = tmp_dep;
-		    dep_cmd.replace("${QMAKE_FILE_NAME}", fi.fileName());
+		    dep_cmd.replace("${QMAKE_FILE_NAME}", fi.filePath());
 		    if(FILE *proc = QT_POPEN(dep_cmd.latin1(), "r")) {
 			while(!feof(proc)) {
 			    int read_in = int(fread(buff, 1, 255, proc));
@@ -1167,8 +1168,10 @@ UnixMakefileGenerator::writeSubdirs(QTextStream &t, bool direct)
 	}
 	if(project->variables()[(*qut_it) + ".CONFIG"].findIndex("phony") != -1)
 	    deps += QString(" ") + "FORCE";
-	t << targ << ":" << deps << "\n\t"
-	  << cmd << endl << endl;
+	t << targ << ":" << deps << "\n";
+        if(!cmd.isEmpty())
+            t << "\t" << cmd << endl;
+        t << endl;
     }
     t <<"FORCE:" << endl << endl;
 }
@@ -1387,7 +1390,7 @@ void UnixMakefileGenerator::init2()
 		QString in = Option::fixPathToTargetOS((*input), FALSE),
 		       out = tmp_out;
 		out.replace("${QMAKE_FILE_BASE}", fi.baseName());
-		out.replace("${QMAKE_FILE_NAME}", fi.fileName());
+		out.replace("${QMAKE_FILE_NAME}", fi.filePath());
 		if(project->variables()[(*it) + ".CONFIG"].findIndex("no_link") == -1)
 		    project->variables()["OBJCOMP"] += out;
 	    }
