@@ -1,9 +1,9 @@
 /****************************************************************************
-** $Id: qt/msvc_nmake.cpp   3.3.3   edited Jul 27 19:14 $
+** $Id: qt/msvc_nmake.cpp   3.3.6   edited Aug 31 2005 $
 **
 ** Implementation of NmakeMakefileGenerator class.
 **
-** Copyright (C) 1992-2003 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of qmake.
 **
@@ -86,8 +86,8 @@ QStringList
 	return aList;
     for(QStringList::Iterator it = Option::cpp_ext.begin(); it != Option::cpp_ext.end(); ++it) {
 	if(file.endsWith(*it)) {
-	    if(!aList.contains(precompH))
-		aList += precompH;
+            if(!precompObj.isEmpty() && !aList.contains(precompObj))
+                aList += precompObj;
 	    break;
 	}
     }
@@ -117,6 +117,8 @@ NmakeMakefileGenerator::writeNmakeParts(QTextStream &t)
 	QString inc = (*incit);
 	if (inc.endsWith("\\"))
 	    inc.truncate(inc.length()-1);
+	if (inc.startsWith("\"") && inc.endsWith("\""))
+	    inc = inc.mid(1, inc.length() - 2);
 	t << " -I\"" << inc << "\"";
     }
     t << " -I\"" << specdir() << "\""
