@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/msvc_vcproj.cpp   3.3.5   edited Aug 31 12:13 $
+** $Id: qt/msvc_vcproj.cpp   3.3.6   edited Feb 16 20:08 $
 **
 ** Implementation of VcprojGenerator class.
 **
@@ -46,57 +46,103 @@
 //#define DEBUG_SOLUTION_GEN
 //#define DEBUG_PROJECT_GEN
 
-// Registry keys for .NET version detection -------------------------
-const char* _regNet2002		= "Microsoft\\VisualStudio\\7.0\\Setup\\VC\\ProductDir";
-const char* _regNet2003		= "Microsoft\\VisualStudio\\7.1\\Setup\\VC\\ProductDir";
+// .NET version detection -------------------------
+enum DotNET {
+    NETUnknown = 0,
+    NET2002 = 0x70,
+    NET2003 = 0x71,
+    NET2005 = 0x80
+};
 
-bool use_net2003_version()
+struct DotNetStrings {
+    DotNET version;
+    const char *versionStr;
+    const char *regKey;
+} dotNetCombo[] = {
+#ifdef Q_OS_WIN64
+    {NET2005, "MSVC.NET 2005 (8.0)", "Wow6432Node\\Microsoft\\VisualStudio\\8.0\\Setup\\VC\\ProductDir"},
+    {NET2005, "MSVC 2005 Express Edition(8.0)", "Wow6432Node\\Microsoft\\VCExpress\\8.0\\Setup\\VC\\ProductDir"},
+    {NET2003, "MSVC.NET 2003 (7.1)", "Wow6432Node\\Microsoft\\VisualStudio\\7.1\\Setup\\VC\\ProductDir"},
+    {NET2002, "MSVC.NET 2002 (7.0)", "Wow6432Node\\Microsoft\\VisualStudio\\7.0\\Setup\\VC\\ProductDir"},
+#else
+    {NET2005, "MSVC.NET 2005 (8.0)", "Microsoft\\VisualStudio\\8.0\\Setup\\VC\\ProductDir"},
+    {NET2005, "MSVC 2005 Express Edition(8.0)", "Microsoft\\VCExpress\\8.0\\Setup\\VC\\ProductDir"},
+    {NET2003, "MSVC.NET 2003 (7.1)", "Microsoft\\VisualStudio\\7.1\\Setup\\VC\\ProductDir"},
+    {NET2002, "MSVC.NET 2002 (7.0)", "Microsoft\\VisualStudio\\7.0\\Setup\\VC\\ProductDir"},
+#endif
+    {NETUnknown, "", ""}
+};
+
+DotNET which_dotnet_version()
 {
 #ifndef Q_OS_WIN32
-    return FALSE; // Always generate 7.0 versions on other platforms
+    return NET2002; // Always generate 7.0 versions on other platforms
 #else
     // Only search for the version once
-    static int current_version = -1;
-    if (current_version!=-1)
-	return (current_version==71);
+    static DotNET current_version = NETUnknown;
+    if(current_version != NETUnknown)
+        return current_version;
 
     // Fallback to .NET 2002
-    current_version = 70;
+    current_version = NET2002;
 
-    // Get registry entries for both versions
-    bool ok = FALSE;
     QSettings setting;
-    QString path2002 = setting.readEntry(_regNet2002);
-    QString path2003 = setting.readEntry(_regNet2003);
-
-    if ( path2002.isNull() || path2003.isNull() ) {
-	// Only have one MSVC, so use that one
-	current_version = (path2003.isNull() ? 70 : 71);
-    } else {
-	// Have both, so figure out the current
-	QString paths = getenv("PATH");
-	QStringList pathlist = QStringList::split(";", paths.lower());
-
-	path2003 = path2003.lower();
-	QStringList::iterator it;
-	for(it=pathlist.begin(); it!=pathlist.end(); ++it) {
-	    if ((*it).contains(path2003)) {
-		current_version = 71;
-	    } else if ((*it).contains(path2002)
-		       && current_version == 71) {
-		fprintf( stderr, "Both .NET 2002 & .NET 2003 directories for VC found in you PATH variable!\nFallback to .NET 2002 project generation" );
-		current_version = 70;
-		break;
-	    }
-	}
+    QStringList warnPath;
+    int installed = 0;
+    int i = 0;
+    for(; dotNetCombo[i].version; ++i) {
+        QString path = setting.readEntry(dotNetCombo[i].regKey);
+        if(!path.isNull()) {
+            ++installed;
+            current_version = dotNetCombo[i].version;
+	    warnPath += QString("%1").arg(dotNetCombo[i].versionStr);
+        }
     }
-    return (current_version==71);
+
+    if (installed < 2)
+        return current_version;
+
+    // More than one version installed, search directory path
+    QString paths = getenv("PATH");
+    QStringList pathlist = QStringList::split(";", paths.lower());
+
+    i = installed = 0;
+    for(; dotNetCombo[i].version; ++i) {
+        QString productPath = setting.readEntry(dotNetCombo[i].regKey).lower();
+        if (productPath.isNull())
+	        continue;
+        QStringList::iterator it;
+        for(it = pathlist.begin(); it != pathlist.end(); ++it) {
+            if((*it).contains(productPath)) {
+                ++installed;
+                current_version = dotNetCombo[i].version;
+                warnPath += QString("%1 in path").arg(dotNetCombo[i].versionStr);
+                    break;
+            }
+        }
+    }
+
+    switch(installed) {
+    case 1:
+	    break;
+    case 0:
+	    warn_msg(WarnLogic, "Generator: MSVC.NET: Found more than one version of Visual Studio, but"
+			     " none in your path! Fallback to lowest version (%s)", warnPath.join(", ").latin1());
+	    break;
+    default:
+	    warn_msg(WarnLogic, "Generator: MSVC.NET: Found more than one version of Visual Studio in"
+			     " your path! Fallback to lowest version (%s)", warnPath.join(", ").latin1());
+	    break;
+    }
+
+    return current_version;
 #endif
 };
 
 // Flatfile Tags ----------------------------------------------------
 const char* _slnHeader70	= "Microsoft Visual Studio Solution File, Format Version 7.00";
 const char* _slnHeader71	= "Microsoft Visual Studio Solution File, Format Version 8.00";
+const char* _slnHeader80        = "Microsoft Visual Studio Solution File, Format Version 9.00";
 				  // The following UUID _may_ change for later servicepacks...
 				  // If so we need to search through the registry at
 				  // HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\VisualStudio\7.0\Projects
@@ -234,7 +280,21 @@ void VcprojGenerator::writeSubDirs(QTextStream &t)
 	return;
     }
 
-    t << (use_net2003_version() ? _slnHeader71 : _slnHeader70);
+    switch(which_dotnet_version()) {
+    case NET2005:
+        t << _slnHeader80;
+        break;
+    case NET2003:
+        t << _slnHeader71;
+        break;
+    case NET2002:
+        t << _slnHeader70;
+        break;
+    default:
+        t << _slnHeader70;
+        warn_msg(WarnLogic, "Generator: MSVC.NET: Unknown version (%d) of MSVC detected for .sln", which_dotnet_version());
+        break;
+    }
 
     QDict<VcsolutionDepend> solution_depends;
 
@@ -360,8 +420,6 @@ nextfile:
 
     // Figure out dependencies
     for(solution_cleanup.first(); solution_cleanup.current(); solution_cleanup.next()) {
-	if(solution_cleanup.current()->targetType == StaticLib)
-	    continue; // Shortcut, Static libs are not dep.
 	int cnt = 0;
 	for(QStringList::iterator dit = solution_cleanup.current()->dependencies.begin();
 	    dit != solution_cleanup.current()->dependencies.end();
@@ -492,7 +550,22 @@ void VcprojGenerator::initProject()
 
     // Own elements -----------------------------
     vcProject.Name = project->first("QMAKE_ORIG_TARGET");
-    vcProject.Version = use_net2003_version() ? "7.10" : "7.00";
+
+    switch(which_dotnet_version()) {
+    case NET2005:
+        vcProject.Version = "8.00";
+        break;
+    case NET2003:
+        vcProject.Version = "7.10";
+        break;
+    case NET2002:
+        vcProject.Version = "7.00";
+        break;
+    default:
+        vcProject.Version = "7.00";
+        break;
+    }
+
     vcProject.ProjectGUID = getProjectUUID().toString().upper();
     vcProject.PlatformName = ( vcProject.Configuration[0].idl.TargetEnvironment == midlTargetWin64 ? "Win64" : "Win32" );
     // These are not used by Qt, but may be used by customers
