@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qcolor.cpp   3.3.5   edited Aug 31 12:13 $
+** $Id: qt/qcolor.cpp   3.3.6   edited Nov 18 23:56 $
 **
 ** Implementation of QColor class
 **
@@ -155,7 +155,7 @@
     treated as 0; hue 540 is treated as 180.
 
     \sa QPalette, QColorGroup, QApplication::setColorSpec(),
-    \link http://www.inforamp.net/~poynton/Poynton-color.html Color FAQ\endlink
+    \link http://www.poynton.com/ColorFAQ.html Color FAQ\endlink
 */
 
 /*****************************************************************************
