@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qdragobject.cpp   3.3.5   edited Aug 31 12:13 $
+** $Id: qt/qdragobject.cpp   3.3.6   edited Jan 30 09:42 $
 **
 ** Implementation of Drag and Drop support
 **
@@ -268,6 +268,9 @@ QDragManager::QDragManager()
     pm_cursor[0] = QPixmap((const char **)move_xpm);
     pm_cursor[1] = QPixmap((const char **)copy_xpm);
     pm_cursor[2] = QPixmap((const char **)link_xpm);
+#if defined(Q_WS_X11)
+    createCursors(); // Xcursors cache can hold only 8 bitmaps (4 cursors)
+#endif
     object = 0;
     dragSource = 0;
     dropWidget = 0;
