@@ -1,9 +1,9 @@
 /****************************************************************************
-** $Id: qt/qeventloop_x11.cpp   3.3.4   edited Nov 11 22:10 $
+** $Id: qt/qeventloop_x11.cpp   3.3.6   edited Aug 31 2005 $
 **
 ** Implementation of QEventLoop class
 **
-** Copyright (C) 2000-2004 Trolltech AS.  All rights reserved.
+** Copyright (C) 2000-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the kernel module of the Qt GUI Toolkit.
 **
@@ -316,7 +316,7 @@ bool QEventLoop::processEvents( ProcessEventsFlags flags )
 		    FD_ZERO(&fdset);
 		    FD_SET(sn->fd, &fdset);
 
-		    int ret;
+		    int ret = -1;
 		    do {
 			switch (type) {
 			case 0: // read
