@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qfont.cpp   3.3.5   edited Aug 31 12:13 $
+** $Id: qt/qfont.cpp   3.3.6   edited Feb 13 11:43 $
 **
 ** Implementation of QFont, QFontMetrics and QFontInfo classes
 **
@@ -2259,7 +2259,7 @@ int QFontMetrics::width( const QString &str, int len ) const
 
 	    if (script >= QFont::Arabic && script <= QFont::Khmer)
 		break;
-            if ( ::category( *ch ) != QChar::Mark_NonSpacing ) {
+            if ( ::category( *ch ) != QChar::Mark_NonSpacing && !qIsZeroWidthChar(ch->unicode())) {
                 QFontEngine *engine = d->engineForScript( script );
 #ifdef QT_CHECK_STATE
                 Q_ASSERT( engine != 0 );
