@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qfont_x11.cpp   3.3.5   edited Aug 31 12:13 $
+** $Id: qt/qfont_x11.cpp   3.3.6   edited Feb 13 10:44 $
 **
 ** Implementation of QFont, QFontMetrics and QFontInfo classes for X11
 **
@@ -667,7 +667,7 @@ int QFontMetrics::width( QChar ch ) const
 	 d->engineData && d->engineData->widthCache[ uc ] )
 	return d->engineData->widthCache[ uc ];
 
-    if ( ::category( ch ) == QChar::Mark_NonSpacing )
+    if ( ::category( ch ) == QChar::Mark_NonSpacing || qIsZeroWidthChar(ch.unicode()))
 	return 0;
 
     QFont::Script script;
@@ -714,7 +714,7 @@ int QFontMetrics::charWidth( const QString &str, int pos ) const
 	QTextEngine layout( cstr.string(), d );
 	layout.itemize( QTextEngine::WidthOnly );
 	width = layout.width( pos-from, 1 );
-    } else if ( ::category( ch ) == QChar::Mark_NonSpacing ) {
+    } else if ( ::category( ch ) == QChar::Mark_NonSpacing || qIsZeroWidthChar(ch.unicode())) {
         width = 0;
     } else {
 	QFontEngine *engine = d->engineForScript( script );
