@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qfontdatabase.cpp   3.3.5   edited Aug 31 12:13 $
+** $Id: qt/qfontdatabase.cpp   3.3.6   edited Feb 9 12:55 $
 **
 ** Implementation of font database class.
 **
@@ -452,148 +452,150 @@ QtFontFamily *QFontDatabasePrivate::family( const QString &f, bool create )
 
 
 #if defined(Q_WS_X11) || defined(Q_WS_WIN)
-static const unsigned short sample_chars[QFont::LastPrivateScript] =
+static const unsigned short sample_chars[QFont::LastPrivateScript][14] =
 {
     // European Alphabetic Scripts
     // Latin,
-    0x0041,
+    { 0x0041, 0x0 },
     // Greek,
-    0x0391,
+    { 0x0391, 0x0 },
     // Cyrillic,
-    0x0410,
+    { 0x0410, 0x0 },
     // Armenian,
-    0x0540,
+    { 0x0540, 0x0 },
     // Georgian,
-    0x10d0,
+    { 0x10d0, 0x0 },
     // Runic,
-    0x16a0,
+    { 0x16a0, 0x0 },
     // Ogham,
-    0x1680,
+    { 0x1680, 0x0 },
     // SpacingModifiers,
-    0x02c6,
+    { 0x02c6, 0x0 },
     // CombiningMarks,
-    0x0300,
+    { 0x0300, 0x0 },
 
     // Middle Eastern Scripts
     // Hebrew,
-    0x05d0,
+    { 0x05d0, 0x0 },
     // Arabic,
-    0x0630,
+    { 0x0630, 0x0 },
     // Syriac,
-    0x0710,
+    { 0x0710, 0x0 },
     // Thaana,
-    0x0780,
+    { 0x0780, 0x0 },
 
     // South and Southeast Asian Scripts
     // Devanagari,
-    0x0910,
+    { 0x0910, 0x0 },
     // Bengali,
-    0x0990,
+    { 0x0990, 0x0 },
     // Gurmukhi,
-    0x0a10,
+    { 0x0a10, 0x0 },
     // Gujarati,
-    0x0a90,
+    { 0x0a90, 0x0 },
     // Oriya,
-    0x0b10,
+    { 0x0b10, 0x0 },
     // Tamil,
-    0x0b90,
+    { 0x0b90, 0x0 },
     // Telugu,
-    0x0c10,
+    { 0x0c10, 0x0 },
     // Kannada,
-    0x0c90,
+    { 0x0c90, 0x0 },
     // Malayalam,
-    0x0d10,
+    { 0x0d10, 0x0 },
     // Sinhala,
-    0x0d90,
+    { 0x0d90, 0x0 },
     // Thai,
-    0x0e10,
+    { 0x0e10, 0x0 },
     // Lao,
-    0x0e81,
+    { 0x0e81, 0x0 },
     // Tibetan,
-    0x0f00,
+    { 0x0f00, 0x0 },
     // Myanmar,
-    0x1000,
+    { 0x1000, 0x0 },
     // Khmer,
-    0x1780,
+    { 0x1780, 0x0 },
 
     // East Asian Scripts
     // Han,
-    0x4e00,
+    { 0x4e00, 0x0 },
     // Hiragana,
-    0x3050,
+    {  0x3050, 0x4e00, 0x25EF, 0x3012, 0x3013, 0x30FB, 0x30FC, 0x5CE0, 0xFF66, 0 },
     // Katakana,
-    0x30b0,
+    { 0x30b0, 0x4e00, 0x25EF, 0x3012, 0x3013, 0x30FB, 0x30FC, 0x5CE0, 0xFF66, 0 },
     // Hangul,
-    0xac00,
+    { 0xac00, 0x0 },
     // Bopomofo,
-    0x3110,
+    { 0x3110, 0x0 },
     // Yi,
-    0xa000,
+    { 0xa000, 0x0 },
 
     // Additional Scripts
     // Ethiopic,
-    0x1200,
+    { 0x1200, 0x0 },
     // Cherokee,
-    0x13a0,
+    { 0x13a0, 0x0 },
     // CanadianAboriginal,
-    0x1410,
+    { 0x1410, 0x0 },
     // Mongolian,
-    0x1800,
+    { 0x1800, 0x0 },
 
     // Symbols
     // CurrencySymbols,
-    0x20aa,
+    { 0x20aa, 0x0 },
     // LetterlikeSymbols,
-    0x2103,
+    { 0x2103, 0x0 },
     // NumberForms,
-    0x2160,
+    { 0x2160, 0x0 },
     // MathematicalOperators,
-    0x222b,
+    { 0x222b, 0x0 },
     // TechnicalSymbols,
-    0x2312,
+    { 0x2312, 0x0 },
     // GeometricSymbols,
-    0x2500,
+    { 0x2500, 0x0 },
     // MiscellaneousSymbols,
-    0x2640,
+    { 0x2640, 0x0 },
     // EnclosedAndSquare,
-    0x2460,
+    { 0x2460, 0x0 },
     // Braille,
-    0x2800,
+    { 0x2800, 0x0 },
 
     // Unicode,
-    0xfffd,
+    { 0xfffd, 0x0 },
 
     // some scripts added in Unicode 3.2
     // Tagalog,
-    0x1700,
+    { 0x1700, 0x0 },
     // Hanunoo,
-    0x1720,
+    { 0x1720, 0x0 },
     // Buhid,
-    0x1740,
+    { 0x1740, 0x0 },
     // Tagbanwa,
-    0x1770,
+    { 0x1770, 0x0 },
 
     // KatakanaHalfWidth
-    0xff65,
+    { 0xff65, 0x0 },
 
     // Limbu
-    0x1901,
+    { 0x1901, 0x0 },
     // TaiLe
-    0x1950,
+    { 0x1950, 0x0 },
 
     // NScripts
-    0x0000,
+    { 0x0000, 0x0 },
     // NoScript
-    0x0000,
+    { 0x0000, 0x0 },
 
     // Han_Japanese
-    0x4e00,
-    // Han_SimplifiedChinese,
-    0x4e00,
-    // Han_TraditionalChinese,
-    0x4e00,
+    { 0x4e00, 0x25EF, 0x3012, 0x3013, 0x30FB, 0x5CE0, 0xFF66, 0 },
+    // Han_SimplifiedChinese, 0x3400 is optional
+    { 0x4e00, 0x201C, 0x3002, 0x6237, 0x9555, 0xFFE5, 0 },
+    // Han_TraditionalChinese, 0xF6B1 is optional
+    // OR Han_HongkongChinese, 0x3435, 0xE000, 0xF6B1 are optional
+    { 0x4e00, 0x201C, 0x3002, 0x6236, 0x9F98, 0xFFE5, 0 },
     // Han_Korean
-    0x4e00
+    { 0x4e00, 0 }
+    // Taiwan would be 0x201C, 0x3002, 0x4E00, 0x9F98, 0xFFE5
 };
 
 #if defined(Q_WS_X11) && !defined(QT_NO_XFTFREETYPE)
@@ -604,23 +606,28 @@ static inline bool requiresOpenType(QFont::Script s)
 }
 #endif
 
-// returns a sample unicode character for the specified script
-static QChar sampleCharacter(QFont::Script script)
-{
-    return QChar(sample_chars[script]);
-}
-
 static inline bool canRender( QFontEngine *fe, QFont::Script script )
 {
     if ( !fe ) return FALSE;
 
-    QChar sample = sampleCharacter(script);
-    bool hasChar = fe->canRender( &sample, 1 );
+    bool hasChar = true;
 
+    if (!sample_chars[script][0])
+        hasChar = false;
+
+    int i = 0;
+    while (hasChar && sample_chars[script][i]){
+        QChar sample(sample_chars[script][i]);
+        if ( !fe->canRender( &sample, 1  ) ) {
+             hasChar = false;
 #ifdef FONT_MATCH_DEBUG
-    if (hasChar)
+	FM_DEBUG("    font has NOT char 0x%04x", sample.unicode() );
+        } else {
 	FM_DEBUG("    font has char 0x%04x", sample.unicode() );
 #endif
+        }
+        ++i;
+    }
 #if defined(Q_WS_X11) && !defined(QT_NO_XFTFREETYPE)
     if (hasChar && requiresOpenType(script)) {
 	QOpenType *ot = fe->openType();
@@ -932,6 +939,14 @@ QFontDatabase::findFont( QFont::Script script, const QFontPrivate *fp,
 	if ( fe ) return fe;
     }
 
+#ifdef Q_WS_WIN
+    if (request.styleStrategy & QFont::PreferDevice) {
+        QFontEngine *fe = loadEngine(script, fp, request, 0, 0, 0);
+        if(fe)
+            return fe;
+    }
+#endif
+
     QString family_name, foundry_name;
     QtFontStyle::Key styleKey;
     styleKey.italic = request.italic;
@@ -949,7 +964,7 @@ QFontDatabase::findFont( QFont::Script script, const QFontPrivate *fp,
 	    QCString locale = setlocale(LC_ALL, NULL);
 	    if (locale.contains("ko"))
 		defaultHan = QFont::Han_Korean;
-	    else if (locale.contains("zh_TW"))
+	    else if (locale.contains("zh_TW") || locale.contains("zh_HK"))
 		defaultHan = QFont::Han_TraditionalChinese;
 	    else if (locale.contains("zh"))
 		defaultHan = QFont::Han_SimplifiedChinese;
@@ -1155,8 +1170,8 @@ QFontDatabase::findFont( QFont::Script script, const QFontPrivate *fp,
 
     if ( fe ) {
 	if ( script != QFont::Unicode && !canRender( fe, script ) ) {
-	    FM_DEBUG( "  WARN: font loaded cannot render sample 0x%04x",
-		      sampleCharacter(script).unicode() );
+	    FM_DEBUG( "  WARN: font loaded cannot render a sample char" );
+
 	    delete fe;
             fe = 0;
 	} else if ( fp ) {
