@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qfontengine_x11.cpp   3.3.5   edited Aug 31 12:13 $
+** $Id: qt/qfontengine_x11.cpp   3.3.6   edited Feb 13 13:35 $
 **
 ** ???
 **
@@ -246,7 +246,7 @@ QFontEngine::Error QFontEngineBox::stringToCMap( const QChar *, int len, glyph_t
     return NoError;
 }
 
-void QFontEngineBox::draw( QPainter *p, int x, int y, const QTextEngine *, const QScriptItem *si, int textFlags )
+void QFontEngineBox::draw( QPainter *p, int x, int y, const QTextEngine *engine, const QScriptItem *si, int textFlags )
 {
     Display *dpy = QPaintDevice::x11AppDisplay();
     Qt::HANDLE hd = p->device()->handle();
@@ -264,13 +264,15 @@ void QFontEngineBox::draw( QPainter *p, int x, int y, const QTextEngine *, const
     int yp = y;
 #endif
 
+    GlyphAttributes *glyphAttributes = engine->glyphAttributes( si );
 
     if ( p->txop > QPainter::TxTranslate ) {
 	int xp = x;
 	int yp = _size + 2;
 	int s = _size - 3;
 	for (int k = 0; k < si->num_glyphs; k++) {
-	    qt_draw_transformed_rect( p, xp, yp, s, s, FALSE );
+	    if (!glyphAttributes[k].zeroWidth)
+    	        qt_draw_transformed_rect( p, xp, yp, s, s, FALSE );
 	    xp += _size;
 	}
     } else {
@@ -284,12 +286,16 @@ void QFontEngineBox::draw( QPainter *p, int x, int y, const QTextEngine *, const
 	    int toDraw = QMIN(64, si->num_glyphs-gl);
 	    int adv = toDraw*_size;
 	    if (x + adv < SHRT_MAX && x > SHRT_MIN) {
+                    int ng = 0;
 		for (int k = 0; k < toDraw; k++) {
-		    rects[k].x = x + (k * _size);
-		    rects[k].y = y - _size + 2;
-		    rects[k].width = rects[k].height = _size - 3;
+            	    if (!glyphAttributes[gl + k].zeroWidth) {
+                            rects[ng].x = x + (k * _size);
+                            rects[ng].y = y - _size + 2;
+                            rects[ng].width = rects[k].height = _size - 3;
+                            ++ng;
+                        }
 		}
-		XDrawRectangles(dpy, hd, gc, rects, toDraw);
+		XDrawRectangles(dpy, hd, gc, rects, ng);
 	    }
 	    gl += toDraw;
 	    x += adv;
@@ -682,6 +688,7 @@ void QFontEngineXLFD::draw( QPainter *p, int x, int y, const QTextEngine *engine
     }
 
     int xpos = x;
+    GlyphAttributes *glyphAttributes = engine->glyphAttributes( si );
 
     if ( si->analysis.bidiLevel % 2 ) {
 	int i = si->num_glyphs;
@@ -694,7 +701,7 @@ void QFontEngineXLFD::draw( QPainter *p, int x, int y, const QTextEngine *engine
 	    int yp = y+offsets[i].y-gi.yoff;
 	    if ( transform )
 		p->map( xp, yp, &xp, &yp );
-	    if (xp < SHRT_MAX && xp > SHRT_MIN)
+	    if (!glyphAttributes[i].zeroWidth && xp < SHRT_MAX && xp > SHRT_MIN)
 		XDrawString16(dpy, hd, gc, xp, yp, chars+i, 1 );
 	}
     } else {
@@ -705,7 +712,7 @@ void QFontEngineXLFD::draw( QPainter *p, int x, int y, const QTextEngine *engine
 		int yp = y+offsets[i].y;
 		if ( transform )
 		    p->map( xp, yp, &xp, &yp );
-		if (xp < SHRT_MAX && xp > SHRT_MIN)
+		if (!glyphAttributes[i].zeroWidth && xp < SHRT_MAX && xp > SHRT_MIN)
 		    XDrawString16(dpy, hd, gc, xp, yp, chars+i, 1 );
 		advance_t adv = advances[i];
 		// 	    qDebug("advance = %d/%d", adv.x, adv.y );
@@ -1733,6 +1740,8 @@ void QFontEngineXft::draw( QPainter *p, int x, int y, const QTextEngine *engine,
     int xorig = x;
     int yorig = y;
 
+    GlyphAttributes *glyphAttributes = engine->glyphAttributes( si );
+
     XftFont *fnt = _font;
     bool transform = FALSE;
     if ( p->txop >= QPainter::TxScale || p->rop != Qt::CopyROP) {
@@ -1830,7 +1839,7 @@ void QFontEngineXft::draw( QPainter *p, int x, int y, const QTextEngine *engine,
     col.color.alpha = 0xffff;
     col.pixel = pen.pixel();
 #ifdef FONTENGINE_DEBUG
-    qDebug("===== drawing %d glyphs reverse=%s ======", si->num_glyphs, si->analysis.bidiLevel % 2?"true":"false" );
+    qDebug("===== drawing %d glyphs reverse=%s ======", si->num_glyphs, si->analysis.bidiLevel % 2?"TRUE":"FALSE" );
     p->save();
     p->setBrush( Qt::white );
     glyph_metrics_t ci = boundingBox( glyphs, advances, offsets, si->num_glyphs );
@@ -1859,10 +1868,10 @@ void QFontEngineXft::draw( QPainter *p, int x, int y, const QTextEngine *engine,
 		    p->map( xp, yp, &xp, &yp );
 #ifdef QT_XFT2
 		FT_UInt glyph = *(glyphs + i);
-		if (xp < SHRT_MAX && xp > SHRT_MIN)
+		if (!glyphAttributes[i].zeroWidth && xp < SHRT_MAX && xp > SHRT_MIN)
 		    XftDrawGlyphs( draw, &col, fnt, xp, yp, &glyph, 1 );
 #else
-		if (xp < SHRT_MAX && xp > SHRT_MIN)
+		if (!glyphAttributes[i].zeroWidth && xp < SHRT_MAX && xp > SHRT_MIN)
 		    XftDrawString16( draw, &col, fnt, xp, yp, (XftChar16 *) (glyphs+i), 1);
 #endif // QT_XFT2
 #ifdef FONTENGINE_DEBUG
@@ -1884,10 +1893,10 @@ void QFontEngineXft::draw( QPainter *p, int x, int y, const QTextEngine *engine,
 		    p->map( xp, yp, &xp, &yp );
 #ifdef QT_XFT2
 		FT_UInt glyph = *(glyphs + i);
-		if (xp < SHRT_MAX && xp > SHRT_MIN)
+		if (!glyphAttributes[i].zeroWidth && xp < SHRT_MAX && xp > SHRT_MIN)
 		    XftDrawGlyphs( draw, &col, fnt, xp, yp, &glyph, 1 );
 #else
-		if (xp < SHRT_MAX && xp > SHRT_MIN)
+		if (!glyphAttributes[i].zeroWidth && xp < SHRT_MAX && xp > SHRT_MIN)
 		    XftDrawString16( draw, &col, fnt, xp, yp, (XftChar16 *) (glyphs+i), 1 );
 #endif // QT_XFT2
 		// 	    qDebug("advance = %d/%d", adv.x, adv.y );
@@ -2209,10 +2218,12 @@ QFontEngine::Type QFontEngineXft::type() const
 
 #ifndef QT_NO_XFTFREETYPE
 
-// #define OT_DEBUG
+#include "qscriptengine_p.h"
+
+//#define OT_DEBUG
 
 #ifdef OT_DEBUG
-static inline char *tag_to_string( FT_ULong tag )
+static inline char *tag_to_string(FT_ULong tag)
 {
     static char string[5];
     string[0] = (tag >> 24)&0xff;
@@ -2225,492 +2236,468 @@ static inline char *tag_to_string( FT_ULong tag )
 #endif
 
 #define DefaultLangSys 0xffff
-#define DefaultScript FT_MAKE_TAG( 'D', 'F', 'L', 'T' )
+#define DefaultScript FT_MAKE_TAG('D', 'F', 'L', 'T')
 
-static const unsigned int supported_scripts [] = {
+enum {
+    RequiresGsub = 1,
+    RequiresGpos = 2
+};
+
+struct OTScripts {
+    unsigned int tag;
+    int flags;
+};
+
+static const OTScripts ot_scripts [] = {
 // 	// European Alphabetic Scripts
 // 	Latin,
-    FT_MAKE_TAG( 'l', 'a', 't', 'n' ),
+    { FT_MAKE_TAG( 'l', 'a', 't', 'n' ), 0 },
 // 	Greek,
-    FT_MAKE_TAG( 'g', 'r', 'e', 'k' ),
+    { FT_MAKE_TAG( 'g', 'r', 'e', 'k' ), 0 },
 // 	Cyrillic,
-    FT_MAKE_TAG( 'c', 'y', 'r', 'l' ),
+    { FT_MAKE_TAG( 'c', 'y', 'r', 'l' ), 0 },
 // 	Armenian,
-        FT_MAKE_TAG( 'a', 'r', 'm', 'n' ),
+    { FT_MAKE_TAG( 'a', 'r', 'm', 'n' ), 0 },
 // 	Georgian,
-    FT_MAKE_TAG( 'g', 'e', 'o', 'r' ),
+    { FT_MAKE_TAG( 'g', 'e', 'o', 'r' ), 0 },
 // 	Runic,
-    FT_MAKE_TAG( 'r', 'u', 'n', 'r' ),
+    { FT_MAKE_TAG( 'r', 'u', 'n', 'r' ), 0 },
 // 	Ogham,
-    FT_MAKE_TAG( 'o', 'g', 'a', 'm' ),
+    { FT_MAKE_TAG( 'o', 'g', 'a', 'm' ), 0 },
 // 	SpacingModifiers,
-    FT_MAKE_TAG( 'D', 'F', 'L', 'T' ),
+    { FT_MAKE_TAG( 'D', 'F', 'L', 'T' ), 0 },
 // 	CombiningMarks,
-    FT_MAKE_TAG( 'D', 'F', 'L', 'T' ),
+    { FT_MAKE_TAG( 'D', 'F', 'L', 'T' ), 0 },
 
 // 	// Middle Eastern Scripts
 // 	Hebrew,
-    FT_MAKE_TAG( 'h', 'e', 'b', 'r' ),
+    { FT_MAKE_TAG( 'h', 'e', 'b', 'r' ), 1 },
 // 	Arabic,
-    FT_MAKE_TAG( 'a', 'r', 'a', 'b' ),
+    { FT_MAKE_TAG( 'a', 'r', 'a', 'b' ), 1 },
 // 	Syriac,
-    FT_MAKE_TAG( 's', 'y', 'r', 'c' ),
+    { FT_MAKE_TAG( 's', 'y', 'r', 'c' ), 1 },
 // 	Thaana,
-    FT_MAKE_TAG( 't', 'h', 'a', 'a' ),
+    { FT_MAKE_TAG( 't', 'h', 'a', 'a' ), 1 },
 
 // 	// South and Southeast Asian Scripts
 // 	Devanagari,
-    FT_MAKE_TAG( 'd', 'e', 'v', 'a' ),
+    { FT_MAKE_TAG( 'd', 'e', 'v', 'a' ), 1 },
 // 	Bengali,
-    FT_MAKE_TAG( 'b', 'e', 'n', 'g' ),
+    { FT_MAKE_TAG( 'b', 'e', 'n', 'g' ), 1 },
 // 	Gurmukhi,
-    FT_MAKE_TAG( 'g', 'u', 'r', 'u' ),
+    { FT_MAKE_TAG( 'g', 'u', 'r', 'u' ), 1 },
 // 	Gujarati,
-    FT_MAKE_TAG( 'g', 'u', 'j', 'r' ),
+    { FT_MAKE_TAG( 'g', 'u', 'j', 'r' ), 1 },
 // 	Oriya,
-    FT_MAKE_TAG( 'o', 'r', 'y', 'a' ),
+    { FT_MAKE_TAG( 'o', 'r', 'y', 'a' ), 1 },
 // 	Tamil,
-    FT_MAKE_TAG( 't', 'a', 'm', 'l' ),
+    { FT_MAKE_TAG( 't', 'a', 'm', 'l' ), 1 },
 // 	Telugu,
-    FT_MAKE_TAG( 't', 'e', 'l', 'u' ),
+    { FT_MAKE_TAG( 't', 'e', 'l', 'u' ), 1 },
 // 	Kannada,
-    FT_MAKE_TAG( 'k', 'n', 'd', 'a' ),
+    { FT_MAKE_TAG( 'k', 'n', 'd', 'a' ), 1 },
 // 	Malayalam,
-    FT_MAKE_TAG( 'm', 'l', 'y', 'm' ),
+    { FT_MAKE_TAG( 'm', 'l', 'y', 'm' ), 1 },
 // 	Sinhala,
     // ### could not find any OT specs on this
-    FT_MAKE_TAG( 's', 'i', 'n', 'h' ),
+    { FT_MAKE_TAG( 's', 'i', 'n', 'h' ), 1 },
 // 	Thai,
-    FT_MAKE_TAG( 't', 'h', 'a', 'i' ),
+    { FT_MAKE_TAG( 't', 'h', 'a', 'i' ), 1 },
 // 	Lao,
-    FT_MAKE_TAG( 'l', 'a', 'o', ' ' ),
+    { FT_MAKE_TAG( 'l', 'a', 'o', ' ' ), 1 },
 // 	Tibetan,
-    FT_MAKE_TAG( 't', 'i', 'b', 't' ),
+    { FT_MAKE_TAG( 't', 'i', 'b', 't' ), 1 },
 // 	Myanmar,
-    FT_MAKE_TAG( 'm', 'y', 'm', 'r' ),
+    { FT_MAKE_TAG( 'm', 'y', 'm', 'r' ), 1 },
 // 	Khmer,
-    FT_MAKE_TAG( 'k', 'h', 'm', 'r' ),
+    { FT_MAKE_TAG( 'k', 'h', 'm', 'r' ), 1 },
 
 // 	// East Asian Scripts
 // 	Han,
-    FT_MAKE_TAG( 'h', 'a', 'n', 'i' ),
+    { FT_MAKE_TAG( 'h', 'a', 'n', 'i' ), 0 },
 // 	Hiragana,
-    FT_MAKE_TAG( 'k', 'a', 'n', 'a' ),
+    { FT_MAKE_TAG( 'k', 'a', 'n', 'a' ), 0 },
 // 	Katakana,
-    FT_MAKE_TAG( 'k', 'a', 'n', 'a' ),
+    { FT_MAKE_TAG( 'k', 'a', 'n', 'a' ), 0 },
 // 	Hangul,
-    FT_MAKE_TAG( 'h', 'a', 'n', 'g' ),
+    { FT_MAKE_TAG( 'h', 'a', 'n', 'g' ), 1 },
 // 	Bopomofo,
-    FT_MAKE_TAG( 'b', 'o', 'p', 'o' ),
+    { FT_MAKE_TAG( 'b', 'o', 'p', 'o' ), 0 },
 // 	Yi,
-    FT_MAKE_TAG( 'y', 'i', ' ', ' ' ),
+    { FT_MAKE_TAG( 'y', 'i', ' ', ' ' ), 0 },
 
 // 	// Additional Scripts
 // 	Ethiopic,
-    FT_MAKE_TAG( 'e', 't', 'h', 'i' ),
+    { FT_MAKE_TAG( 'e', 't', 'h', 'i' ), 0 },
 // 	Cherokee,
-    FT_MAKE_TAG( 'c', 'h', 'e', 'r' ),
+    { FT_MAKE_TAG( 'c', 'h', 'e', 'r' ), 0 },
 // 	CanadianAboriginal,
-    FT_MAKE_TAG( 'c', 'a', 'n', 's' ),
+    { FT_MAKE_TAG( 'c', 'a', 'n', 's' ), 0 },
 // 	Mongolian,
-    FT_MAKE_TAG( 'm', 'o', 'n', 'g' ),
-
+    { FT_MAKE_TAG( 'm', 'o', 'n', 'g' ), 0 },
 // 	// Symbols
 // 	CurrencySymbols,
-    FT_MAKE_TAG( 'D', 'F', 'L', 'T' ),
+    { FT_MAKE_TAG( 'D', 'F', 'L', 'T' ), 0 },
 // 	LetterlikeSymbols,
-    FT_MAKE_TAG( 'D', 'F', 'L', 'T' ),
+    { FT_MAKE_TAG( 'D', 'F', 'L', 'T' ), 0 },
 // 	NumberForms,
-    FT_MAKE_TAG( 'D', 'F', 'L', 'T' ),
+    { FT_MAKE_TAG( 'D', 'F', 'L', 'T' ), 0 },
 // 	MathematicalOperators,
-    FT_MAKE_TAG( 'D', 'F', 'L', 'T' ),
+    { FT_MAKE_TAG( 'D', 'F', 'L', 'T' ), 0 },
 // 	TechnicalSymbols,
-    FT_MAKE_TAG( 'D', 'F', 'L', 'T' ),
+    { FT_MAKE_TAG( 'D', 'F', 'L', 'T' ), 0 },
 // 	GeometricSymbols,
-    FT_MAKE_TAG( 'D', 'F', 'L', 'T' ),
+    { FT_MAKE_TAG( 'D', 'F', 'L', 'T' ), 0 },
 // 	MiscellaneousSymbols,
-    FT_MAKE_TAG( 'D', 'F', 'L', 'T' ),
+    { FT_MAKE_TAG( 'D', 'F', 'L', 'T' ), 0 },
 // 	EnclosedAndSquare,
-    FT_MAKE_TAG( 'D', 'F', 'L', 'T' ),
+    { FT_MAKE_TAG( 'D', 'F', 'L', 'T' ), 0 },
 // 	Braille,
-    FT_MAKE_TAG( 'b', 'r', 'a', 'i' ),
-
+    { FT_MAKE_TAG( 'b', 'r', 'a', 'i' ), 0 },
 //                Unicode, should be used
-    FT_MAKE_TAG( 'D', 'F', 'L', 'T' )
+    { FT_MAKE_TAG( 'D', 'F', 'L', 'T' ), 0 }
     // ### where are these?
-// 	FT_MAKE_TAG( 'b', 'y', 'z', 'm' ),
-//     FT_MAKE_TAG( 'D', 'F', 'L', 'T' ),
+// 	{ FT_MAKE_TAG( 'b', 'y', 'z', 'm' ), 0 },
+//     { FT_MAKE_TAG( 'D', 'F', 'L', 'T' ), 0 },
     // ### Hangul Jamo
-//     FT_MAKE_TAG( 'j', 'a', 'm', 'o' ),
+//     { FT_MAKE_TAG( 'j', 'a', 'm', 'o' ), 0 },
 };
 
 QOpenType::QOpenType(QFontEngineXft *fe)
-    : xft(fe), gdef( 0 ), gsub( 0 ), gpos( 0 ), current_script( 0 )
+    : fontEngine(fe), gdef(0), gsub(0), gpos(0), current_script(0)
 {
-    face = xft->face();
-    hasGDef = hasGSub = hasGPos = TRUE;
-    str = tmp = 0;
-    positions = 0;
+    face = fe->face();
+    otl_buffer_new(face->memory, &otl_buffer);
     tmpAttributes = 0;
     tmpLogClusters = 0;
+
+    FT_Error error;
+    if ((error = TT_Load_GDEF_Table(face, &gdef))) {
+#ifdef OT_DEBUG
+        qDebug("error loading gdef table: %d", error);
+#endif
+        gdef = 0;
+    }
+
+    if ((error = TT_Load_GSUB_Table(face, &gsub, gdef))) {
+        gsub = 0;
+#ifdef OT_DEBUG
+        if (error != FT_Err_Table_Missing) {
+            qDebug("error loading gsub table: %d", error);
+        } else {
+            qDebug("face doesn't have a gsub table");
+        }
+#endif
+    }
+
+    if ((error = TT_Load_GPOS_Table(face, &gpos, gdef))) {
+        gpos = 0;
+#ifdef OT_DEBUG
+        qDebug("error loading gpos table: %d", error);
+#endif
+    }
+    
+    for (uint i = 0; i < QFont::NScripts; ++i)
+        supported_scripts[i] = checkScript(i);
 }
 
 QOpenType::~QOpenType()
 {
-    if ( gpos )
-	TT_Done_GPOS_Table( gpos );
-    if ( gsub )
-	TT_Done_GSUB_Table( gsub );
-    if ( gdef )
-	TT_Done_GDEF_Table( gdef );
-    if ( str )
-	TT_GSUB_String_Done( str );
-    if ( tmp )
-	TT_GSUB_String_Done( tmp );
-    if (positions)
-	free(positions);
-    if ( tmpAttributes )
-	free(tmpAttributes);
+    if (gpos)
+        TT_Done_GPOS_Table(gpos);
+    if (gsub)
+        TT_Done_GSUB_Table(gsub);
+    if (gdef)
+        TT_Done_GDEF_Table(gdef);
+    if (otl_buffer)
+        otl_buffer_free(otl_buffer);
+    if (tmpAttributes)
+        free(tmpAttributes);
     if (tmpLogClusters)
-	free(tmpLogClusters);
+        free(tmpLogClusters);
 }
 
-bool QOpenType::supportsScript( unsigned int script )
+bool QOpenType::checkScript(unsigned int script)
 {
-    if ( current_script == supported_scripts[script] )
-	return TRUE;
+    assert(script < QFont::NScripts);
 
+    uint tag = ot_scripts[script].tag;
+    int requirements = ot_scripts[script].flags;
+
+    if (requirements & RequiresGsub) {
+        if (!gsub)
+            return FALSE;
+        
+        FT_UShort script_index;
+        FT_Error error = TT_GSUB_Select_Script(gsub, tag, &script_index);
+        if (error) {
 #ifdef OT_DEBUG
-    qDebug("trying to load tables for script %d (%s))", script, tag_to_string( supported_scripts[script] ));
+            qDebug("could not select script %d in GSub table: %d", (int)script, error);
 #endif
-
-    FT_Error error;
-    if ( !gdef ) {
-	if ( (error = TT_Load_GDEF_Table( face, &gdef )) ) {
-//  	    qDebug("error loading gdef table: %d", error );
-	    hasGDef = FALSE;
-	}
+            return FALSE;
+        }
     }
-
-    if ( !gsub ) {
-	if ( (error = TT_Load_GSUB_Table( face, &gsub, gdef )) ) {
-	    if ( error != FT_Err_Table_Missing ) {
-//  		qDebug("error loading gsub table: %d", error );
-		return FALSE;
-	    } else {
-//  		qDebug("face doesn't have a gsub table" );
-		hasGSub = FALSE;
-	    }
-	}
-    }
-
-    if ( !gpos ) {
-	if ( (error = TT_Load_GPOS_Table( face, &gpos, gdef )) ) {
-//  		qDebug("error loading gpos table: %d", error );
-	    hasGPos = FALSE;
-	}
-    }
-
-    if ( loadTables( script ) ) {
-	return TRUE;
-    }
-    return FALSE;
-}
-
-bool QOpenType::loadTables( FT_ULong script)
-{
-    assert( script < QFont::Unicode );
-    // find script in our list of supported scripts.
-    unsigned int stag = supported_scripts[script];
-
-    FT_Error error = TT_GSUB_Select_Script( gsub, stag, &script_index );
-    if ( error ) {
+    
+    if (requirements & RequiresGpos) {
+        if (!gpos)
+            return FALSE;
+        
+        FT_UShort script_index;
+        FT_Error error = TT_GPOS_Select_Script(gpos, script, &script_index);
+        if (error) {
 #ifdef OT_DEBUG
- 	qDebug("could not select script %d: %d", (int)script, error );
+            qDebug("could not select script in gpos table: %d", error);
 #endif
-	if ( stag == DefaultScript ) {
-	    // try to load default language system
-	    error = TT_GSUB_Select_Script( gsub, DefaultScript, &script_index );
-	    if ( error )
-		return FALSE;
-	} else {
-	    return FALSE;
-	}
-    }
-    script = stag;
-
-#ifdef OT_DEBUG
-    qDebug("script %s has script index %d", tag_to_string(script), script_index );
-#endif
-
-#ifdef OT_DEBUG
-    TTO_FeatureList featurelist = gsub->FeatureList;
-    int numfeatures = featurelist.FeatureCount;
-    qDebug("gsub table has %d features", numfeatures );
-    for( int i = 0; i < numfeatures; i++ ) {
-	TTO_FeatureRecord *r = featurelist.FeatureRecord + i;
-	qDebug("   feature '%s'", tag_to_string(r->FeatureTag));
-    }
-#endif
-    if ( hasGPos ) {
-	FT_UShort script_index;
-	error = TT_GPOS_Select_Script( gpos, script, &script_index );
-	if ( error ) {
-// 	    qDebug("could not select script in gpos table: %d", error );
-	    return TRUE;
-	}
-
-	TTO_FeatureList featurelist = gpos->FeatureList;
-
-	int numfeatures = featurelist.FeatureCount;
-
-#ifdef OT_DEBUG
- 	qDebug("gpos table has %d features", numfeatures );
-#endif
-
-	for( int i = 0; i < numfeatures; i++ ) {
-	    TTO_FeatureRecord *r = featurelist.FeatureRecord + i;
-	    FT_UShort feature_index;
-	    TT_GPOS_Select_Feature( gpos, r->FeatureTag, script_index, 0xffff, &feature_index );
-
-#ifdef OT_DEBUG
- 	    qDebug("   feature '%s'", tag_to_string(r->FeatureTag));
-#endif
-	}
-
+            return FALSE;
+        }
 
     }
-
-    current_script = script;
-
     return TRUE;
 }
 
-void QOpenType::init(glyph_t *glyphs, GlyphAttributes *glyphAttributes, int num_glyphs,
-		     unsigned short *logClusters, int len, int /*char_offset*/)
+
+void QOpenType::selectScript(unsigned int script, const Features *features)
 {
-    if ( !str )
-	TT_GSUB_String_New(&str);
-    if ( str->allocated < (uint)num_glyphs )
-	TT_GSUB_String_Allocate( str, num_glyphs );
-    if ( !tmp )
-	TT_GSUB_String_New(&tmp);
-    if ( tmp->allocated < (uint)num_glyphs )
-	TT_GSUB_String_Allocate( tmp, num_glyphs );
-    tmp->length = 0;
+    if (current_script == script)
+        return;
+    
+    assert(script < QFont::NScripts);
+    // find script in our list of supported scripts.
+    uint tag = ot_scripts[script].tag;
 
-    length = len;
+    if (gsub && features) {
+#ifdef OT_DEBUG
+        {
+            TTO_FeatureList featurelist = gsub->FeatureList;
+            int numfeatures = featurelist.FeatureCount;
+            qDebug("gsub table has %d features", numfeatures);
+            for(int i = 0; i < numfeatures; i++) {
+                TTO_FeatureRecord *r = featurelist.FeatureRecord + i;
+                qDebug("   feature '%s'", tag_to_string(r->FeatureTag));
+            }
+        }
+#endif
+        TT_GSUB_Clear_Features(gsub);
+        FT_UShort script_index;
+        FT_Error error = TT_GSUB_Select_Script(gsub, tag, &script_index);
+        if (!error) {
+#ifdef OT_DEBUG
+            qDebug("script %s has script index %d", tag_to_string(script), script_index);
+#endif
+            while (features->tag) {
+                FT_UShort feature_index;
+                error = TT_GSUB_Select_Feature(gsub, features->tag, script_index, 0xffff, &feature_index);
+                if (!error) {
+#ifdef OT_DEBUG
+                    qDebug("  adding feature %s", tag_to_string(features->tag));
+#endif
+                    TT_GSUB_Add_Feature(gsub, feature_index, features->property);
+                }
+                ++features;
+            }
+        }
+    }
+    
+    if (gpos) {
+        TT_GPOS_Clear_Features(gpos);
+        FT_UShort script_index;
+        FT_Error error = TT_GPOS_Select_Script(gpos, tag, &script_index);
+        if (!error) {
+#ifdef OT_DEBUG
+            {
+                TTO_FeatureList featurelist = gpos->FeatureList;
+                int numfeatures = featurelist.FeatureCount;
+                qDebug("gpos table has %d features", numfeatures);
+                for(int i = 0; i < numfeatures; i++) {
+                    TTO_FeatureRecord *r = featurelist.FeatureRecord + i;
+                    FT_UShort feature_index;
+                    TT_GPOS_Select_Feature(gpos, r->FeatureTag, script_index, 0xffff, &feature_index);
+                    qDebug("   feature '%s'", tag_to_string(r->FeatureTag));
+                }
+            }
+#endif
+            FT_ULong *feature_tag_list;
+            error = TT_GPOS_Query_Features(gpos, script_index, 0xffff, &feature_tag_list);
+            if (!error) {
+                while (*feature_tag_list) {
+                    FT_UShort feature_index;
+                    error = TT_GPOS_Select_Feature(gpos, *feature_tag_list, script_index, 0xffff, &feature_index);
+                    if (!error)
+                        TT_GPOS_Add_Feature(gpos, feature_index, PositioningProperties);
+                    ++feature_tag_list;
+                }
+            }
+        }
+    }
 
-    Q_ASSERT(len == num_glyphs);
-    memcpy(str->string, glyphs, num_glyphs*sizeof(unsigned short));
+    current_script = script;
+}
 
-    for (int i = 0; i < num_glyphs; ++i)
-	str->character_index[i] = i;
+#ifdef OT_DEBUG
+static void dump_string(OTL_Buffer buffer)
+{
+    for (uint i = 0; i < buffer->in_length; ++i) {
+        qDebug("    %x: cluster=%d", buffer->in_string[i].gindex, buffer->in_string[i].cluster);
+    }
+}
+#endif
+
+extern void qt_heuristicPosition(QShaperItem *item);
+
+void QOpenType::shape(QShaperItem *item, const unsigned int *properties)
+{
+    length = item->num_glyphs;
+
+    otl_buffer_clear(otl_buffer);
+
+    tmpAttributes = (GlyphAttributes *) realloc(tmpAttributes, length*sizeof(GlyphAttributes));
+    tmpLogClusters = (unsigned int *) realloc(tmpLogClusters, length*sizeof(unsigned int));
+    for (int i = 0; i < length; ++i) {
+        otl_buffer_add_glyph(otl_buffer, item->glyphs[i], properties ? properties[i] : 0, i);
+        tmpAttributes[i] = item->attributes[i];
+        tmpLogClusters[i] = item->log_clusters[i];
+    }
 
 #ifdef OT_DEBUG
     qDebug("-----------------------------------------");
-    qDebug("log clusters before shaping:");
-    for (int j = 0; j < length; j++)
-	qDebug("    log[%d] = %d", j, logClusters[j] );
-    qDebug("original glyphs:");
-    for (int i = 0; i < num_glyphs; ++i)
-	qDebug("   glyph=%4x char_index=%d mark: %d cmb: %d", str->string[i], str->character_index[i], glyphAttributes[i].mark, glyphAttributes[i].combiningClass);
+//     qDebug("log clusters before shaping:");
+//     for (int j = 0; j < length; j++)
+//         qDebug("    log[%d] = %d", j, item->log_clusters[j]);
+    qDebug("original glyphs: %p", item->glyphs);
+    for (int i = 0; i < length; ++i)
+        qDebug("   glyph=%4x", otl_buffer->in_string[i].gindex);
+//     dump_string(otl_buffer);
 #endif
-    str->length = num_glyphs;
-    orig_nglyphs = num_glyphs;
 
-    tmpLogClusters = (unsigned short *) realloc( tmpLogClusters, length*sizeof(unsigned short) );
-    memcpy( tmpLogClusters, logClusters, length*sizeof(unsigned short) );
-    tmpAttributes = (GlyphAttributes *) realloc( tmpAttributes, num_glyphs*sizeof(GlyphAttributes) );
-    memcpy( tmpAttributes, glyphAttributes, num_glyphs*sizeof(GlyphAttributes) );
+    loadFlags = FT_LOAD_DEFAULT;
+
+    if (gsub)
+        TT_GSUB_Apply_String(gsub, otl_buffer);
+
+#ifdef OT_DEBUG
+//     qDebug("log clusters before shaping:");
+//     for (int j = 0; j < length; j++)
+//         qDebug("    log[%d] = %d", j, item->log_clusters[j]);
+    qDebug("shaped glyphs:");
+    for (int i = 0; i < length; ++i)
+        qDebug("   glyph=%4x", otl_buffer->in_string[i].gindex);
+    qDebug("-----------------------------------------");
+//     dump_string(otl_buffer);
+#endif
 }
 
-void QOpenType::applyGSUBFeature(unsigned int featureTag, bool *where)
+bool QOpenType::positionAndAdd(QShaperItem *item, bool doLogClusters)
 {
-    FT_UShort feature_index;
-    FT_Error err = TT_GSUB_Select_Feature( gsub, featureTag, script_index, 0xffff, &feature_index);
-    if (err) {
-#ifdef OT_DEBUG
-// 	qDebug("feature %s not covered by table or language system", tag_to_string( featureTag ));
+    if (gpos) {
+#ifdef Q_WS_X11
+        Q_ASSERT(fontEngine->type() == QFontEngine::Xft);
+        face = lockFTFace(static_cast<QFontEngineXft *>(fontEngine)->font());
 #endif
-	return;
-    }
-
-#ifdef OT_DEBUG
-    qDebug("applying GSUB feature %s with index %d", tag_to_string( featureTag ), feature_index);
-#endif
-
-    unsigned char w[256];
-    unsigned char *where_to_apply = w;
-    if (str->length > 255)
-	where_to_apply = (unsigned char *)malloc(str->length*sizeof(unsigned char));
-
-    memset(where_to_apply, 1, str->length);
-    if (where) {
-	for (uint i = 0; i < str->length; ++i) {
-	    where_to_apply[i] = where[str->character_index[i]];
-	}
-#ifdef OT_DEBUG
-// 	for (int i = 0; i < (int)str->length; ++i)
-// 	    qDebug("   apply=%s", where_to_apply[i] ? "true" : "false");
+        memset(otl_buffer->positions, 0, otl_buffer->in_length*sizeof(OTL_PositionRec));
+        // #### check that passing "FALSE,FALSE" is correct
+        TT_GPOS_Apply_String(face, gpos, loadFlags, otl_buffer, FALSE, FALSE);
+#ifdef Q_WS_X11
+        unlockFTFace(static_cast<QFontEngineXft *>(fontEngine)->font());
 #endif
     }
-
-    TT_GSUB_Apply_Feature(gsub, feature_index, where_to_apply, &str, &tmp);
-
-    if (w != where_to_apply)
-	free(where_to_apply);
-
-#ifdef OT_DEBUG
-    qDebug("after applying:");
-    for ( int i = 0; i < (int)str->length; i++) {
-      qDebug("   %4x", str->string[i]);
-    }
-#endif
-    positioned = FALSE;
-}
-
-
-extern void q_heuristicPosition( QTextEngine *engine, QScriptItem *item );
-
-void QOpenType::applyGPOSFeatures()
-{
-#ifdef OT_DEBUG
-    qDebug("applying GPOS features");
-#endif
-    // currently just apply all features
-
-    if ( hasGPos ) {
-	positions = (TTO_GPOS_Data *) realloc( positions, str->length*sizeof(TTO_GPOS_Data) );
-	memset(positions, 0, str->length*sizeof(TTO_GPOS_Data));
-
-	TTO_FeatureList featurelist = gpos->FeatureList;
-	int numfeatures = featurelist.FeatureCount;
-
-	for( int i = 0; i < numfeatures; i++ ) {
-	    TTO_FeatureRecord *r = featurelist.FeatureRecord + i;
-	    FT_UShort feature_index;
-	    FT_Error error = TT_GPOS_Select_Feature( gpos, r->FeatureTag, script_index, 0xffff, &feature_index );
-	    if (error != FT_Err_Ok)
-		continue;
-
-#ifdef OT_DEBUG
-	    qDebug("applying POS feature %s with index %d", tag_to_string( r->FeatureTag ), feature_index);
-#endif
-
-	    str->pos = 0;
-	    // ensure the face has the correct size and matrix set
-	    face = lockFTFace(xft->_font);
-	    TT_GPOS_Apply_Feature( face, gpos, feature_index, FT_LOAD_DEFAULT, str, &positions, FALSE, FALSE );
-	    unlockFTFace(xft->_font);
-	}
-    }
-    positioned = TRUE;
-}
-
-const int *QOpenType::mapping(int &len)
-{
-    len = str->length;
-    return str->character_index;
-}
-
-void QOpenType::appendTo(QTextEngine *engine, QScriptItem *si, bool doLogClusters)
-{
-#ifdef OT_DEBUG
-    qDebug("QOpenType::finalize:");
-#endif
+    
     // make sure we have enough space to write everything back
-    engine->ensureSpace( si->num_glyphs + str->length );
+    if (item->num_glyphs < (int)otl_buffer->in_length) {
+        item->num_glyphs = otl_buffer->in_length;
+        return FALSE;
+    }
 
-    glyph_t *glyphs = engine->glyphs( si ) + si->num_glyphs;
-    advance_t *advances = engine->advances(si) + si->num_glyphs;
-    qoffset_t *offsets = engine->offsets(si) + si->num_glyphs;
-    GlyphAttributes *glyphAttributes = engine->glyphAttributes( si ) + si->num_glyphs;
+    for (unsigned int i = 0; i < otl_buffer->in_length; ++i) {
+        item->glyphs[i] = otl_buffer->in_string[i].gindex;
+        item->attributes[i] = tmpAttributes[otl_buffer->in_string[i].cluster];
+        if (i && otl_buffer->in_string[i].cluster == otl_buffer->in_string[i-1].cluster)
+            item->attributes[i].clusterStart = FALSE;
+    }
+    item->num_glyphs = otl_buffer->in_length;
 
-    memcpy(glyphs, str->string, str->length*sizeof(glyph_t));
     if (doLogClusters) {
-	// we can't do this for indic, as we pass the stuf in syllables and it's easier to do it in the shaper.
-	unsigned short *logClusters = engine->logClusters( si );
-	int clusterStart = 0;
-	int oldCi = 0;
-	for ( int i = 0; i < (int)str->length; i++ ) {
-	    int ci = str->character_index[i];
-	    glyphAttributes[i] = tmpAttributes[ci];
-	    // 	qDebug("   ci[%d] = %d mark=%d, cmb=%d, cs=%d tmplc=%d",
-	    // 	       i, ci, glyphAttributes[i].mark, glyphAttributes[i].combiningClass, glyphAttributes[i].clusterStart,  tmpLogClusters[ci]);
-	    if ( !glyphAttributes[i].mark && glyphAttributes[i].clusterStart && ci != oldCi ) {
-		for ( int j = oldCi; j < ci; j++ )
-		    logClusters[j] = clusterStart;
-		clusterStart = i;
-		oldCi = ci;
-	    }
-	}
-	for ( int j = oldCi; j < length; j++ )
-	    logClusters[j] = clusterStart;
+        // we can't do this for indic, as we pass the stuf in syllables and it's easier to do it in the shaper.
+        unsigned short *logClusters = item->log_clusters;
+        int clusterStart = 0;
+        int oldCi = 0;
+        for (unsigned int i = 0; i < otl_buffer->in_length; ++i) {
+            int ci = otl_buffer->in_string[i].cluster;
+            //         qDebug("   ci[%d] = %d mark=%d, cmb=%d, cs=%d",
+            //                i, ci, glyphAttributes[i].mark, glyphAttributes[i].combiningClass, glyphAttributes[i].clusterStart);
+            if (!item->attributes[i].mark && item->attributes[i].clusterStart && ci != oldCi) {
+                for (int j = oldCi; j < ci; j++)
+                    logClusters[j] = clusterStart;
+                clusterStart = i;
+                oldCi = ci;
+            }
+        }
+        for (int j = oldCi; j < length; j++)
+            logClusters[j] = clusterStart;
     }
 
     // calulate the advances for the shaped glyphs
 //     qDebug("unpositioned: ");
-    ((QFontEngineXft *)si->fontEngine)->recalcAdvances( str->length, glyphs, advances );
-    for ( int i = 0; i < (int)str->length; i++ ) {
-	if ( glyphAttributes[i].mark )
-	    advances[i] = 0;
-// 	    qDebug("   adv=%d (mark=%d)", advances[i], glyphAttributes[i].mark);
-    }
-    si->num_glyphs += str->length;
+    static_cast<QFontEngineXft *>(item->font)->recalcAdvances(item->num_glyphs, item->glyphs, item->advances);
 
     // positioning code:
-    if ( hasGPos && positioned) {
-	float scale = si->fontEngine->scale();
-//   	qDebug("positioned glyphs:" );
-	for ( int i = 0; i < (int)str->length; i++) {
-// 	    qDebug("    %d:\t orig advance: %d\tadv=(%d/%d)\tpos=(%d/%d)\tback=%d\tnew_advance=%d", i,
-// 		   advances[i], (int)(positions[i].x_advance >> 6), (int)(positions[i].y_advance >> 6 ),
-// 		   (int)(positions[i].x_pos >> 6 ), (int)(positions[i].y_pos >> 6),
-// 		   positions[i].back, positions[i].new_advance );
-	    // ###### fix the case where we have y advances. How do we handle this in Uniscribe?????
-	    if ( positions[i].new_advance ) {
-		advances[i] = si->analysis.bidiLevel % 2 ?
-			      -qRound((positions[i].x_advance >> 6)*scale) :
-			      qRound((positions[i].x_advance >> 6)*scale);
-		//advances[i].y = -positions[i].y_advance >> 6;
-	    } else {
-		advances[i] += si->analysis.bidiLevel % 2 ?
-			      -qRound((positions[i].x_advance >> 6)*scale) :
-			      qRound((positions[i].x_advance >> 6)*scale);
-		//advances[i].y -= positions[i].y_advance >> 6;
-	    }
-	    offsets[i].x = qRound((positions[i].x_pos >> 6)*scale);
-	    offsets[i].y = -qRound((positions[i].y_pos >> 6)*scale);
-	    int back = positions[i].back;
-	    if ( si->analysis.bidiLevel % 2 ) {
-		while ( back-- )
-		    offsets[i].x -= advances[i-back];
-	    } else {
-		while ( back )
-		    offsets[i].x -= advances[i-(back--)];
-	    }
-// 	    qDebug("   ->\tadv=%d\tpos=(%d/%d)",
-// 		   advances[i], offsets[i].x, offsets[i].y );
-	}
-	si->hasPositioning = TRUE;
+    if (gpos) {
+	float scale = item->font->scale();
+        OTL_Position positions = otl_buffer->positions;
+
+//         qDebug("positioned glyphs:");
+        for (unsigned int i = 0; i < otl_buffer->in_length; i++) {
+//             qDebug("    %d:\t orig advance: (%d/%d)\tadv=(%d/%d)\tpos=(%d/%d)\tback=%d\tnew_advance=%d", i,
+//                    glyphs[i].advance.x.toInt(), glyphs[i].advance.y.toInt(),
+//                    (int)(positions[i].x_advance >> 6), (int)(positions[i].y_advance >> 6),
+//                    (int)(positions[i].x_pos >> 6), (int)(positions[i].y_pos >> 6),
+//                    positions[i].back, positions[i].new_advance);
+            // ###### fix the case where we have y advances. How do we handle this in Uniscribe?????
+            if (positions[i].new_advance) {
+                item->advances[i] = item->flags & QTextEngine::RightToLeft
+                                    ? -qRound((positions[i].x_advance >> 6)*scale) 
+                                    :  qRound((positions[i].x_advance >> 6)*scale);
+            } else {
+                item->advances[i] += item->flags & QTextEngine::RightToLeft
+                                     ? -qRound((positions[i].x_advance >> 6)*scale) 
+                                     :  qRound((positions[i].x_advance >> 6)*scale);
+            }
+	    item->offsets[i].x = qRound((positions[i].x_pos >> 6)*scale);
+	    item->offsets[i].y = -qRound((positions[i].y_pos >> 6)*scale);
+            int back = positions[i].back;
+            if (item->flags & QTextEngine::RightToLeft) {
+                while (back--) {
+                    item->offsets[i].x -= item->advances[i-back];
+                }
+            } else {
+                while (back) {
+                    item->offsets[i].x -= item->advances[i-back];
+                    --back;
+                }
+            }
+//             qDebug("   ->\tadv=%d\tpos=(%d/%d)",
+//                    glyphs[i].advance.x.toInt(), glyphs[i].offset.x.toInt(), glyphs[i].offset.y.toInt());
+        }
+        item->has_positioning = TRUE;
     } else {
-	q_heuristicPosition( engine, si );
+        qt_heuristicPosition(item);
     }
 
 #ifdef OT_DEBUG
-    qDebug("log clusters after shaping:");
-    if (doLogClusters) {
-	for (int j = 0; j < length; j++)
-	    qDebug("    log[%d] = %d", j, engine->logClusters(si)[j] );
-    }
+//     if (doLogClusters) {
+//         qDebug("log clusters after shaping:");
+//         for (int j = 0; j < length; j++)
+//             qDebug("    log[%d] = %d", j, item->log_clusters[j]);
+//     }
     qDebug("final glyphs:");
-    for (int i = 0; i < (int)str->length; ++i)
-	qDebug("   glyph=%4x char_index=%d mark: %d cmp: %d, clusterStart: %d width=%d",
-	       glyphs[i], str->character_index[i], glyphAttributes[i].mark, glyphAttributes[i].combiningClass, glyphAttributes[i].clusterStart,
-	       advances[i]);
+    for (int i = 0; i < (int)otl_buffer->in_length; ++i)
+        qDebug("   glyph=%4x char_index=%d mark: %d cmp: %d, clusterStart: %d advance=%d offset=%d/%d",
+               item->glyphs[i], otl_buffer->in_string[i].cluster, item->attributes[i].mark,
+               item->attributes[i].combiningClass, item->attributes[i].clusterStart,
+               item->advances[i],
+               item->offsets[i].x, item->offsets[i].y);
     qDebug("-----------------------------------------");
 #endif
+    return TRUE;
 }
 
 #endif
