@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qimageformatinterface_p.h   3.3.5   edited Aug 31 12:17 $
+** $Id: qt/qimageformatinterface_p.h   3.3.6   edited Jan 30 09:46 $
 **
 ** ...
 **
@@ -40,6 +40,9 @@
 #include <private/qcom_p.h>
 #endif // QT_H
 
+#if __GNUC__ - 0 > 3
+#pragma GCC system_header
+#endif
 
 //
 //  W A R N I N G
