@@ -1,11 +1,11 @@
 /****************************************************************************
-** $Id: qt/qjpegio.cpp   3.3.3   edited Jul 21 14:16 $
+** $Id: qt/qjpegio.cpp   3.3.6   edited Aug 31 2005 $
 **
 ** Implementation of JPEG QImage IOHandler
 **
 ** Created : 990521
 **
-** Copyright (C) 1992-2003 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the kernel module of the Qt GUI Toolkit.
 **
@@ -254,7 +254,7 @@ void read_jpeg_image(QImageIO* iio)
 	    scaleSize( sWidth, sHeight, cinfo.output_width, cinfo.output_height, sMode );
 //	    qDebug( "Scaling the jpeg to %i x %i", sWidth, sHeight, sModeStr );
 
-            bool created = FALSE;
+	    bool created = FALSE;
 	    if ( cinfo.output_components == 3 || cinfo.output_components == 4) {
 		created = image.create( sWidth, sHeight, 32 );
 	    } else if ( cinfo.output_components == 1 ) {
@@ -264,8 +264,8 @@ void read_jpeg_image(QImageIO* iio)
 	    } else {
 		// Unsupported format
 	    }
-            if (!created)
-                image = QImage();
+	    if (!created)
+		image = QImage();
 
 	    if (!image.isNull()) {
 		QImage tmpImage( cinfo.output_width, 1, 32 );
@@ -299,11 +299,11 @@ void read_jpeg_image(QImageIO* iio)
 		    }
 		}
 		(void) jpeg_finish_decompress(&cinfo);
-            }
+	    }
 
 	} else {
 
-            bool created = false;
+	    bool created = FALSE;
 	    if ( cinfo.output_components == 3 || cinfo.output_components == 4) {
 		created = image.create( cinfo.output_width, cinfo.output_height, 32 );
 	    } else if ( cinfo.output_components == 1 ) {
@@ -313,41 +313,41 @@ void read_jpeg_image(QImageIO* iio)
 	    } else {
 		// Unsupported format
 	    }
-            if (!created)
-                image = QImage();
+	    if (!created)
+		image = QImage();
 
 	    if (!image.isNull()) {
 		uchar** lines = image.jumpTable();
 		while (cinfo.output_scanline < cinfo.output_height)
 		    (void) jpeg_read_scanlines(&cinfo,
-                                               lines + cinfo.output_scanline,
-                                               cinfo.output_height);
+		                               lines + cinfo.output_scanline,
+		                               cinfo.output_height);
 		(void) jpeg_finish_decompress(&cinfo);
 
-                if ( cinfo.output_components == 3 ) {
-                    // Expand 24->32 bpp.
-                    for (uint j=0; j<cinfo.output_height; j++) {
-                        uchar *in = image.scanLine(j) + cinfo.output_width * 3;
-                        QRgb *out = (QRgb*)image.scanLine(j);
+		if ( cinfo.output_components == 3 ) {
+		    // Expand 24->32 bpp.
+		    for (uint j=0; j<cinfo.output_height; j++) {
+			uchar *in = image.scanLine(j) + cinfo.output_width * 3;
+			QRgb *out = (QRgb*)image.scanLine(j);
 
-                        for (uint i=cinfo.output_width; i--; ) {
-                            in-=3;
-                            out[i] = qRgb(in[0], in[1], in[2]);
-                        }
-                    }
-                }
-            }
+			for (uint i=cinfo.output_width; i--; ) {
+			    in-=3;
+			    out[i] = qRgb(in[0], in[1], in[2]);
+			}
+		    }
+		}
+	    }
         }
 
-        if (!image.isNull()) {
-            if ( cinfo.density_unit == 1 ) {
-                image.setDotsPerMeterX( int(100. * cinfo.X_density / 2.54) );
-                image.setDotsPerMeterY( int(100. * cinfo.Y_density / 2.54) );
-            } else if ( cinfo.density_unit == 2 ) {
-                image.setDotsPerMeterX( int(100. * cinfo.X_density) );
-                image.setDotsPerMeterY( int(100. * cinfo.Y_density) );
-            }
-        }
+	if (!image.isNull()) {
+	    if ( cinfo.density_unit == 1 ) {
+	        image.setDotsPerMeterX( int(100. * cinfo.X_density / 2.54) );
+	        image.setDotsPerMeterY( int(100. * cinfo.Y_density / 2.54) );
+	    } else if ( cinfo.density_unit == 2 ) {
+		image.setDotsPerMeterX( int(100. * cinfo.X_density) );
+		image.setDotsPerMeterY( int(100. * cinfo.Y_density) );
+	    }
+	}
 
 	iio->setImage(image);
 	iio->setStatus(image.isNull());
@@ -485,19 +485,19 @@ void write_jpeg_image(QImageIO* iio)
 
 	jpeg_set_defaults(&cinfo);
 
-        float diffInch = QABS(image.dotsPerMeterX()*2.54/100. - qRound(image.dotsPerMeterX()*2.54/100.))
-                         + QABS(image.dotsPerMeterY()*2.54/100. - qRound(image.dotsPerMeterY()*2.54/100.));
-        float diffCm = (QABS(image.dotsPerMeterX()/100. - qRound(image.dotsPerMeterX()/100.))
-                        + QABS(image.dotsPerMeterY()/100. - qRound(image.dotsPerMeterY()/100.)))*2.54;
-        if (diffInch < diffCm) {
-            cinfo.density_unit = 1; // dots/inch
-            cinfo.X_density = qRound(image.dotsPerMeterX()*2.54/100.);
-            cinfo.Y_density = qRound(image.dotsPerMeterY()*2.54/100.);
-        } else {
-            cinfo.density_unit = 2; // dots/cm
-            cinfo.X_density = (image.dotsPerMeterX()+50) / 100;
-            cinfo.Y_density = (image.dotsPerMeterY()+50) / 100;
-        }
+	float diffInch = QABS(image.dotsPerMeterX()*2.54/100. - qRound(image.dotsPerMeterX()*2.54/100.))
+	                 + QABS(image.dotsPerMeterY()*2.54/100. - qRound(image.dotsPerMeterY()*2.54/100.));
+	float diffCm = (QABS(image.dotsPerMeterX()/100. - qRound(image.dotsPerMeterX()/100.))
+	                + QABS(image.dotsPerMeterY()/100. - qRound(image.dotsPerMeterY()/100.)))*2.54;
+	if (diffInch < diffCm) {
+	    cinfo.density_unit = 1; // dots/inch
+	    cinfo.X_density = qRound(image.dotsPerMeterX()*2.54/100.);
+	    cinfo.Y_density = qRound(image.dotsPerMeterY()*2.54/100.);
+	} else {
+	    cinfo.density_unit = 2; // dots/cm
+	    cinfo.X_density = (image.dotsPerMeterX()+50) / 100;
+	    cinfo.Y_density = (image.dotsPerMeterY()+50) / 100;
+	}
 
 	int quality = iio->quality() >= 0 ? QMIN(iio->quality(),100) : 75;
 #if defined(Q_OS_UNIXWARE)
