@@ -1,11 +1,11 @@
 /****************************************************************************
-** $Id: qt/qnamespace.h   3.3.1   edited Dec 13 17:15 $
+** $Id: qt/qnamespace.h   3.3.6   edited Feb 22 17:15 $
 **
 ** Definition of Qt namespace (as class for compiler compatibility)
 **
 ** Created : 980927
 **
-** Copyright (C) 1992-2003 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the kernel module of the Qt GUI Toolkit.
 **
@@ -705,12 +705,14 @@ public:
 	MV_10_DOT_1     = 0x0003,
 	MV_10_DOT_2     = 0x0004,
 	MV_10_DOT_3     = 0x0005,
+	MV_10_DOT_4     = 0x0006,
 
 	//Code names
 	MV_CHEETAH      = MV_10_DOT_0,
 	MV_PUMA         = MV_10_DOT_1,
 	MV_JAGUAR       = MV_10_DOT_2,
-	MV_PANTHER      = MV_10_DOT_3
+	MV_PANTHER      = MV_10_DOT_3,
+	MV_TIGER        = MV_10_DOT_4
     };
 
     // documented in qapplication_win.cpp
@@ -725,6 +727,7 @@ public:
 	WV_2000 	= 0x0020,
 	WV_XP		= 0x0030,
 	WV_2003		= 0x0040,
+	WV_VISTA 	= 0x0080,
 	WV_NT_based	= 0x00f0,
 
 	WV_CE           = 0x0100,
