@@ -1,11 +1,11 @@
 /****************************************************************************
-** $Id: qt/qpixmap_x11.cpp   3.3.4   edited Jan 20 12:07 $
+** $Id: qt/qpixmap_x11.cpp   3.3.6   edited Aug 31 2005 $
 **
 ** Implementation of QPixmap class for X11
 **
 ** Created : 940501
 **
-** Copyright (C) 1992-2004 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the kernel module of the Qt GUI Toolkit.
 **
@@ -309,6 +309,9 @@ void QPixmap::init( int w, int h, int d, bool bitmap, Optimization optim )
 
     int dd = x11Depth();
 
+    if ( d != -1 )
+        dd = d;
+
     if ( optim == DefaultOptim )		// use default optimization
 	optim = defOptim;
 
