@@ -1,11 +1,11 @@
 /****************************************************************************
-** $Id: qt/qsizegrip.cpp   3.3.3   edited Nov 28 2003 $
+** $Id: qt/qsizegrip.cpp   3.3.6   edited Aug 31 2005 $
 **
 ** Implementation of QSizeGrip class
 **
 ** Created : 980119
 **
-** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the kernel module of the Qt GUI Toolkit.
 **
@@ -223,15 +223,9 @@ void QSizeGrip::mouseMoveEvent( QMouseEvent * e )
 	h = ms.height();
 
     if (QApplication::reverseLayout()) {
-	if (tlw->isTopLevel()) {
-	    int x = tlw->geometry().x() + ( np.x()-p.x() );
-	    int y = tlw->geometry().y();
-	    tlw->setGeometry(x,y,w,h);
-	} else {
-	    tlw->resize( w, h );
-	    if (tlw->size() == QSize(w,h))
-		tlw->move( tlw->x() + ( np.x()-p.x() ), tlw->y() );
-	}
+	tlw->resize( w, h );
+	if (tlw->size() == QSize(w,h))
+	    tlw->move( tlw->x() + ( np.x()-p.x() ), tlw->y() );
     } else {
 	tlw->resize( w, h );
     }
