@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qtextengine.cpp   3.3.5   edited Aug 31 12:13 $
+** $Id: qt/qtextengine.cpp   3.3.6   edited Oct 19 11:03 $
 **
 ** Text engine classes
 **
@@ -225,7 +225,9 @@ static void qAppendItems(QTextEngine *engine, int &start, int &stop, BidiControl
 		item.analysis.script = s;
 		item.analysis.bidiLevel = level;
 	    } else {
-		continue;
+                if (i - start < 32000)
+                    continue;
+                start = i;
 	    }
 
 	    item.position = i;
@@ -265,7 +267,7 @@ static void bidiItemize( QTextEngine *engine, bool rightToLeft, int mode )
     QChar::Direction dir = rightToLeft ? QChar::DirR : QChar::DirL;
     BidiStatus status;
     QChar::Direction sdir = direction( *unicode );
-    if ( sdir != QChar::DirL && sdir != QChar::DirR && sdir != QChar::DirEN && sdir != QChar::DirAN )
+    if ( sdir != QChar::DirL && sdir != QChar::DirR && sdir != QChar::DirAL && sdir != QChar::DirEN && sdir != QChar::DirAN )
 	sdir = QChar::DirON;
     else
         dir = QChar::DirON;
@@ -800,46 +802,73 @@ static void calcLineBreaks(const QString &str, QCharAttributes *charAttributes)
 {
     int len = str.length();
     if (!len)
-	return;
+        return;
 
     const QChar *uc = str.unicode();
     int cls = lineBreakClass(*uc);
     if (cls >= QUnicodeTables::LineBreak_CM)
-	cls = QUnicodeTables::LineBreak_ID;
+        cls = QUnicodeTables::LineBreak_ID;
 
     charAttributes[0].softBreak = FALSE;
+    charAttributes[0].whiteSpace = (cls == QUnicodeTables::LineBreak_SP);
+    charAttributes[0].charStop = TRUE;
 
     for (int i = 1; i < len; ++i) {
-	int ncls = lineBreakClass(uc[i]);
+        int ncls = ::lineBreakClass(uc[i]);
+        int category = ::category(uc[i]);
+        if (category == QChar::Mark_NonSpacing)
+            goto nsm;
+        
+        if (category == QChar::Other_Surrogate) {
+            // char stop only on first pair
+            if (uc[i].unicode() >= 0xd800 && uc[i].unicode() < 0xdc00 && i < len-1
+                && uc[i+1].unicode() >= 0xdc00 && uc[i+1].unicode() < 0xe000)
+                goto nsm;
+            // ### correctly handle second surrogate
+        }
 
-	if (ncls == QUnicodeTables::LineBreak_SP || ncls == QUnicodeTables::LineBreak_CM) {
-	    charAttributes[i].softBreak = FALSE;
-	    continue;
-	}
-#ifndef Q_WS_X11
-	if (ncls >= QUnicodeTables::LineBreak_SA) {
-	    // ### handle complex case
-	    ncls = QUnicodeTables::LineBreak_ID;
-	}
-	int brk = charAttributes[i].charStop ? breakTable[cls][ncls] : (int)Pbk;
-#else
-	if (cls == QUnicodeTables::LineBreak_SA && ncls == QUnicodeTables::LineBreak_SA)
-            // two complex chars (thai or lao), thai_attributes has already set this correctly
+        if (ncls == QUnicodeTables::LineBreak_SP) {
+            charAttributes[i].softBreak = FALSE;
+            charAttributes[i].whiteSpace = TRUE;
+            charAttributes[i].charStop = TRUE;
+            cls = ncls;
             continue;
-        int tcls = ncls;
-        if (tcls >= QUnicodeTables::LineBreak_SA)
-            tcls = QUnicodeTables::LineBreak_ID;
-        if (cls >= QUnicodeTables::LineBreak_SA)
-            cls = QUnicodeTables::LineBreak_ID;
+        }
 
-	int brk = charAttributes[i].charStop ? breakTable[cls][tcls] : (int)Pbk;
-#endif
-	if (brk == Ibk)
-	    charAttributes[i].softBreak = (lineBreakClass(uc[i-1]) == QUnicodeTables::LineBreak_SP);
-	else
-	    charAttributes[i].softBreak = (brk == Dbk);
-//	qDebug("char = %c %04x, cls=%d, ncls=%d, brk=%d soft=%d", uc[i].cell(), uc[i].unicode(), cls, ncls, brk, charAttributes[i].softBreak);
-	cls = ncls;
+
+	if (cls == QUnicodeTables::LineBreak_SA && ncls == QUnicodeTables::LineBreak_SA) {
+            // two complex chars (thai or lao), thai_attributes might override, but here
+            // we do a best guess
+            charAttributes[i].softBreak = TRUE;
+            charAttributes[i].whiteSpace = FALSE;
+            charAttributes[i].charStop = TRUE;
+            cls = ncls;
+            continue;
+        }
+        {
+	    int tcls = ncls;
+	    if (tcls >= QUnicodeTables::LineBreak_SA)
+		tcls = QUnicodeTables::LineBreak_ID;
+	    if (cls >= QUnicodeTables::LineBreak_SA)
+		cls = QUnicodeTables::LineBreak_ID;
+
+	    bool softBreak;
+	    int brk = breakTable[cls][tcls];
+	    if (brk == Ibk)
+		softBreak = (cls == QUnicodeTables::LineBreak_SP);
+	    else
+		softBreak = (brk == Dbk);
+//        qDebug("char = %c %04x, cls=%d, ncls=%d, brk=%d soft=%d", uc[i].cell(), uc[i].unicode(), cls, ncls, brk, charAttributes[i].softBreak);
+	    charAttributes[i].softBreak = softBreak;
+	    charAttributes[i].whiteSpace = FALSE;
+	    charAttributes[i].charStop = TRUE;
+	    cls = ncls;
+	}
+        continue;
+    nsm:
+        charAttributes[i].softBreak = FALSE;
+        charAttributes[i].whiteSpace = FALSE;
+        charAttributes[i].charStop = FALSE;
     }
 }
 
@@ -945,24 +974,26 @@ const QCharAttributes *QTextEngine::attributes()
     if ( !items.d )
 	itemize();
 
+    ensureSpace(string.length());
+    charAttributes = (QCharAttributes *) memory;
+    calcLineBreaks(string, charAttributes);
+    
     for ( int i = 0; i < items.size(); i++ ) {
 	QScriptItem &si = items[i];
-	int from = si.position;
-	int len = length( i );
 #ifdef Q_WS_WIN
         int script = uspScriptForItem(this, i);
-        if(script >= QFont::Devanagari && script <= QFont::Khmer)
-            ScriptBreak( (WCHAR *)string.ucs2()+from, len, &si.analysis, charAttributes + from);
-        else
-	    scriptEngines[script].charAttributes( script, string, from, len, charAttributes );
 #else
         int script = si.analysis.script;
-	Q_ASSERT( script < QFont::NScripts );
-	scriptEngines[script].charAttributes( script, string, from, len, charAttributes );
 #endif
+	Q_ASSERT( script < QFont::NScripts );
+        AttributeFunction attributes = scriptEngines[script].charAttributes;
+        if (!attributes)
+            continue;
+	int from = si.position;
+	int len = length( i );
+	attributes( script, string, from, len, charAttributes );
     }
 
-    calcLineBreaks(string, charAttributes);
     haveCharAttributes = TRUE;
     return charAttributes;
 }
@@ -1077,7 +1108,7 @@ void QTextEngine::itemize( int mode )
     if ( string.length() == 0 )
 	return;
 
-    if ( !(mode & NoBidi) ) {
+    if ( 1 || !(mode & NoBidi) ) {
 	if ( direction == QChar::DirON )
 	    direction = basicDirection( string );
 	bidiItemize( this, direction == QChar::DirR, mode );
