@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qtextengine_unix.cpp   3.3.5   edited Aug 31 12:13 $
+** $Id: qt/qtextengine_unix.cpp   3.3.6   edited Oct 18 13:14 $
 **
 ** Text engine classes
 **
@@ -71,31 +71,53 @@ void QTextEngine::shape( int item ) const
 	return;
 
     QFont::Script script = (QFont::Script)si.analysis.script;
-    int from = si.position;
-    int len = length( item );
-
     si.glyph_data_offset = used;
 
     if ( !si.fontEngine )
 	si.fontEngine = fnt->engineForScript( script );
     si.fontEngine->ref();
 
-    if ( !widthOnly ) {
 	si.ascent = si.fontEngine->ascent();
 	si.descent = si.fontEngine->descent();
-    }
+    si.num_glyphs = 0;
 
     if ( si.fontEngine && si.fontEngine != (QFontEngine*)-1 ) {
-	assert( script < QFont::NScripts );
-	scriptEngines[script].shape( script, string, from, len, (QTextEngine *)this, &si );
+        QShaperItem shaper_item;
+        shaper_item.script = si.analysis.script;
+        shaper_item.string = &string;
+        shaper_item.from = si.position;
+        shaper_item.length = length(item);
+        shaper_item.font = si.fontEngine;
+        shaper_item.num_glyphs = QMAX(int(num_glyphs - used), shaper_item.length);
+        shaper_item.flags = si.analysis.bidiLevel % 2 ? RightToLeft : 0;
+        shaper_item.has_positioning = FALSE;
+
+        while (1) {
+//         qDebug("    . num_glyphs=%d, used=%d, item.num_glyphs=%d", num_glyphs, used, shaper_item.num_glyphs);
+            ensureSpace(shaper_item.num_glyphs);
+            shaper_item.num_glyphs = num_glyphs - used;
+//          qDebug("    .. num_glyphs=%d, used=%d, item.num_glyphs=%d", num_glyphs, used, shaper_item.num_glyphs);
+            shaper_item.glyphs = glyphs(&si);
+            shaper_item.advances = advances(&si);
+            shaper_item.offsets = offsets(&si);
+            shaper_item.attributes = glyphAttributes(&si);
+            shaper_item.log_clusters = logClusters(&si);
+            if (scriptEngines[shaper_item.script].shape(&shaper_item))
+                break;
+        }
+
+        si.num_glyphs = shaper_item.num_glyphs;
+        si.hasPositioning = shaper_item.has_positioning;
     }
     ((QTextEngine *)this)->used += si.num_glyphs;
 
     si.width = 0;
     advance_t *advances = this->advances( &si );
     advance_t *end = advances + si.num_glyphs;
-    while ( advances < end )
+    while ( advances < end ) {
+//         qDebug("advances[%d] = %d", advances - this->advances(&si), *advances);
 	si.width += *(advances++);
+    }
 
     return;
 }
