@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qurloperator.cpp   3.3.5   edited Aug 31 12:13 $
+** $Id: qt/qurloperator.cpp   3.3.6   edited Jan 25 15:07 $
 **
 ** Implementation of QUrlOperator class
 **
@@ -374,6 +374,9 @@ QUrlOperator::~QUrlOperator()
 */
 const QNetworkOperation *QUrlOperator::startOperation( QNetworkOperation *op )
 {
+    if ( !d->networkProtocol )
+        getNetworkProtocol();
+    
     if ( d->networkProtocol && (d->networkProtocol->supportedOperations()&op->operation()) ) {
 	d->networkProtocol->addOperation( op );
 	if ( op->operation() == QNetworkProtocol::OpListChildren )
