@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qwidget_x11.cpp   3.3.5   edited Aug 31 12:13 $
+** $Id: qt/qwidget_x11.cpp   3.3.6   edited Jan 27 16:30 $
 **
 ** Implementation of QWidget and QWindow classes for X11
 **
@@ -1966,7 +1966,8 @@ static void do_size_hints( QWidget* widget, QWExtra *x )
     s.flags |= PWinGravity;
     s.win_gravity = qt_widget_tlw_gravity;	// usually NorthWest
     // reset in case it was set
-    qt_widget_tlw_gravity = NorthWestGravity;
+    qt_widget_tlw_gravity =
+        QApplication::reverseLayout() ? NorthEastGravity : NorthWestGravity;
     XSetWMNormalHints( widget->x11Display(), widget->winId(), &s );
 }
 
