@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qdns.cpp   3.3.5   edited Aug 31 12:13 $
+** $Id: qt/qdns.cpp   3.3.6   edited Sep 22 11:49 $
 **
 ** Implementation of QDns class.
 **
@@ -2559,13 +2559,13 @@ void QDns::doResInit()
 	while ( !stream.atEnd() ) {
 	    line = stream.readLine();
             QStringList list = QStringList::split( " ", line );
-	    if( list.isEmpty() )
+	    if ( line.startsWith( "#" ) || list.count() < 2 )
                 continue;
             const QString type = list[0].lower();
 
 	    if ( type == "nameserver" ) {
 		QHostAddress *address = new QHostAddress();
-		if ( address->setAddress( QString(line[1]) ) ) {
+		if ( address->setAddress( QString(list[1]) ) ) {
 		    // only add ipv6 addresses from resolv.conf if
 		    // this host supports ipv6.
 		    if ( address->isIPv4Address() || ipv6support )
