@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qftp.cpp   3.3.5   edited Aug 31 12:13 $
+** $Id: qt/qftp.cpp   3.3.6   edited Sep 21 09:32 $
 **
 ** Implementation of QFtp class.
 **
@@ -962,7 +962,7 @@ bool QFtpPI::startNextCmd()
     state = Waiting;
 #ifndef QT_NO_TEXTCODEC
     if ( qt_ftp_filename_codec ) {
-	int len;
+	int len = 0;
 	QCString enc = qt_ftp_filename_codec->fromUnicode(currentCmd,len);
 	commandSocket.writeBlock( enc.data(), len );
     } else
