@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qgl.cpp   3.3.5   edited Aug 31 12:13 $
+** $Id: qt/qgl.cpp   3.3.6   edited Feb 13 15:31 $
 **
 ** Implementation of OpenGL classes for Qt
 **
@@ -2006,7 +2006,9 @@ void QGLWidget::qglColor( const QColor& c ) const
     if ( ctx ) {
 	if ( ctx->format().rgba() )
 	    glColor3ub( c.red(), c.green(), c.blue() );
-	else if ( !cmap.isEmpty() ) { // QGLColormap in use?
+        
+	else if ( ctx->device() == context()->device()
+                  && !cmap.isEmpty() ) { // QGLColormap in use?
 	    int i = cmap.find( c.rgb() );
 	    if ( i < 0 )
 		i = cmap.findNearest( c.rgb() );
@@ -2031,7 +2033,8 @@ void QGLWidget::qglClearColor( const QColor& c ) const
 	if ( ctx->format().rgba() )
 	    glClearColor( (GLfloat)c.red() / 255.0, (GLfloat)c.green() / 255.0,
 			  (GLfloat)c.blue() / 255.0, (GLfloat) 0.0 );
-	else if ( !cmap.isEmpty() ) { // QGLColormap in use?
+	else if ( ctx->device() == context()->device() 
+                  && !cmap.isEmpty() ) { // QGLColormap in use?
 	    int i = cmap.find( c.rgb() );
 	    if ( i < 0 )
 		i = cmap.findNearest( c.rgb() );
