@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qgl_x11.cpp   3.3.5   edited Aug 31 12:13 $
+** $Id: qt/qgl_x11.cpp   3.3.6   edited Sep 5 2005 $
 **
 ** Implementation of OpenGL classes for Qt
 **
@@ -1068,6 +1068,8 @@ void QGLWidget::init( QGLContext *context, const QGLWidget *shareWidget )
 void QGLWidget::reparent( QWidget* parent, WFlags f, const QPoint& p,
 			  bool showIt )
 {
+    if (glcx)
+        glcx->doneCurrent();
     QWidget::reparent( parent, f, p, FALSE );
     if ( showIt )
 	show();
