@@ -4,7 +4,7 @@
 **
 ** Created : 001103
 **
-** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the sql module of the Qt GUI Toolkit.
 **
@@ -296,14 +296,16 @@ bool QMYSQLResult::reset ( const QString& query )
     if ( !driver()-> isOpen() || driver()->isOpenError() )
 	return FALSE;
     cleanup();
-    if ( mysql_real_query( d->mysql, query, query.length() ) ) {
+
+    const char *encQuery = query.ascii();
+    if ( mysql_real_query( d->mysql, encQuery, qstrlen(encQuery) ) ) {
 	setLastError( qMakeError("Unable to execute query", QSqlError::Statement, d ) );
 	return FALSE;
     }
     if ( isForwardOnly() ) {
- 	if ( isActive() || isValid() ) // have to empty the results from previous query
+	if ( isActive() || isValid() ) // have to empty the results from previous query
 	    fetchLast();
- 	d->result = mysql_use_result( d->mysql );
+	d->result = mysql_use_result( d->mysql );
     } else {
 	d->result = mysql_store_result( d->mysql );
     }
@@ -500,7 +502,7 @@ bool QMYSQLDriver::open( const QString& db,
 				NULL,
 				optionFlags ) )
     {
-	if ( mysql_select_db( d->mysql, db )) {
+	if ( !db.isEmpty() && mysql_select_db( d->mysql, db )) {
 	    setLastError( qMakeError("Unable open database '" + db + "'", QSqlError::Connection, d ) );
 	    mysql_close( d->mysql );
 	    setOpenError( TRUE );
