@@ -4,7 +4,7 @@
 **
 ** Created : 2000-11-03
 **
-** Copyright (C) 2000 Trolltech AS.  All rights reserved.
+** Copyright (C) 2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the sql module of the Qt GUI Toolkit.
 **
@@ -212,7 +212,9 @@ void qt_debug_buffer( const QString& msg, QSqlRecord* cursor )
     The filter (see setFilter()) and sort defined within the table are
     used instead of the filter and sort set on the cursor. For sorting
     options see setSort(), sortColumn(), sortAscending() and
-    sortDescending().
+    sortDescending(). Note that sorting operations will not behave as
+    expected if you are using a QSqlSelectCursor because it uses
+    user-defined SQL queries to obtain data.
 
     The text used to represent NULL, TRUE and FALSE values can be
     changed with setNullText(), setTrueText() and setFalseText()
