@@ -4,7 +4,7 @@
 **
 ** Created : 2000-11-03
 **
-** Copyright (C) 2000 Trolltech AS.  All rights reserved.
+** Copyright (C) 2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the sql module of the Qt GUI Toolkit.
 **
@@ -500,7 +500,7 @@ void QSqlCursor::remove( int pos )
     Sets the generated flag for the field \a name to \a generated. If
     the field does not exist, nothing happens. Only fields that have
     \a generated set to TRUE are included in the SQL that is
-    generated.
+    generated by insert(), update() or del().
 
     \sa isGenerated()
 */
