@@ -4,7 +4,7 @@
 **
 ** Created : 2000-11-03
 **
-** Copyright (C) 2000-2003 Trolltech AS.  All rights reserved.
+** Copyright (C) 2000-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the sql module of the Qt GUI Toolkit.
 **
@@ -387,6 +387,11 @@ public:
     database(connectionName)\endlink to retrieve a pointer to the
     database connection.
 
+    \warning If you add a database with the same name as an
+    existing database, the new database will replace the old one.
+    This will happen automatically if you call this function more
+    than once without specifying \a connectionName.
+
     \sa database() removeDatabase()
 */
 QSqlDatabase* QSqlDatabase::addDatabase( const QString& type, const QString& connectionName )
