@@ -4,7 +4,7 @@
 **
 ** Created : 2000-11-03
 **
-** Copyright (C) 2000-2003 Trolltech AS.  All rights reserved.
+** Copyright (C) 2000-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the sql module of the Qt GUI Toolkit.
 **
@@ -133,12 +133,10 @@ void QSqlResultShared::slotResultDestroyed()
     To access the data returned by a query, use the value() method.
     Each field in the data returned by a SELECT statement is accessed
     by passing the field's position in the statement, starting from 0.
-    This makes using \c{SELECT *} queries inadvisable because the
-    order of the fields returned is indeterminate. For the sake of
-    efficiency there are no methods to access a field by name. (The \l
-    QSqlCursor class provides a higher level interface that generates
-    SQL automatically and through which fields are accessible by
-    name.)
+    Information about the fields can be obtained via QSqlDatabase::record().
+    For the sake of efficiency there are no functions to access a field
+    by name. (The \l QSqlCursor class provides a higher-level interface
+    with field access by name and automatic SQL generation.)
 
     QSqlQuery supports prepared query execution and the binding of
     parameter values to placeholders. Some databases don't support
