@@ -1,11 +1,11 @@
 /****************************************************************************
-** $Id: qt/qstylefactory.cpp   3.3.4   edited Mar 25 2004 $
+** $Id: qt/qstylefactory.cpp   3.3.6   edited Feb 20 17:00 $
 **
 ** Implementation of QStyleFactory class
 **
 ** Created : 001103
 **
-** Copyright (C) 1992-2002 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the widgets module of the Qt GUI Toolkit.
 **
@@ -106,14 +106,14 @@ QStyleFactoryPrivate::~QStyleFactoryPrivate()
     plugin (see \l QStylePlugin).
 
     QStyleFactory::keys() returns a list of valid keys, typically
-    including "windows", "motif", "cde", "motifplus", "platinum",
-    "sgi" and "compact". Depending on the platform, "windowsxp",
-    "aqua" or "macintosh" may be available.
+    including "Windows", "Motif", "CDE", "MotifPlus", "Platinum",
+    "SGI" and "Compact". Depending on the platform, "WindowsXP",
+    "Aqua" or "Macintosh" may be available.
 */
 
 /*!
-    Creates a QStyle object that matches \a key. This is either a
-    built-in style, or a style from a style plugin.
+    Creates a QStyle object that matches \a key case-insensitively.
+    This is either a built-in style, or a style from a style plugin.
 
     \sa keys()
 */
