@@ -1,9 +1,9 @@
 /****************************************************************************
-** $Id: qt/qcom_p.h   3.3.3   edited May 27 2003 $
+** $Id: qt/qcom_p.h   3.3.6   edited Jan 30 09:46 $
 **
 ** ...
 **
-** Copyright (C) 2001-2002 Trolltech AS.  All rights reserved.
+** Copyright (C) 2001-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the tools module of the Qt GUI Toolkit.
 **
@@ -53,6 +53,10 @@
 #include "quuid.h"
 #endif // QT_H
 
+#if __GNUC__ - 0 > 3
+#pragma GCC system_header
+#endif
+
 #ifndef QT_NO_COMPONENT
 
 class QObject;
