@@ -1,11 +1,11 @@
 /****************************************************************************
-** $Id: qt/qdatastream.cpp   3.3.4   edited Oct 12 11:45 $
+** $Id: qt/qdatastream.cpp   3.3.6   edited Aug 31 2005 $
 **
 ** Implementation of QDataStream class
 **
 ** Created : 930831
 **
-** Copyright (C) 1992-2004 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the tools module of the Qt GUI Toolkit.
 **
@@ -968,9 +968,9 @@ QDataStream &QDataStream::operator<<( Q_INT64 i )
 #endif
 	dev->writeBlock( buf, strlen(buf) );
     } else if ( version() < 6 ) {
-	Q_UINT32 i1, i2;
-	*this >> i2 >> i1;
-	i = ((Q_UINT64)i1 << 32) + i2;
+	Q_UINT32 i1 = i & 0xffffffff;
+	Q_UINT32 i2 = i >> 32;
+	*this << i2 << i1;
     } else if ( noswap ) {			// no conversion needed
 	dev->writeBlock( (char *)&i, sizeof(Q_INT64) );
     } else {					// swap bytes
