@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qfile.cpp   3.3.5   edited Aug 31 12:13 $
+** $Id: qt/qfile.cpp   3.3.6   edited Jan 24 15:50 $
 **
 ** Implementation of QFile class
 **
@@ -307,8 +307,15 @@ bool QFile::remove()
 
 void QFile::flush()
 {
-    if ( isOpen() && fh )			// can only flush open/buffered
-	fflush( fh );				//   file
+    if ( isOpen() && fh ) {			// can only flush open/buffered file
+        if ( fflush( fh )  ) {		// write error
+            if ( errno == ENOSPC )			// disk is full
+                setStatus( IO_ResourceError );
+            else
+                setStatus( IO_WriteError );
+            setErrorStringErrno( errno );
+        }
+    }
 }
 
 /*! \reimp
