@@ -1,9 +1,9 @@
 /****************************************************************************
-** $Id: qt/qthreadinstance_p.h   3.2.2   edited Aug 13 14:08 $
+** $Id: qt/qthreadinstance_p.h   3.3.6   edited Aug 31 2005 $
 **
 ** ...
 **
-** Copyright (C) 2003 Trolltech AS.  All rights reserved.
+** Copyright (C) 2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the tools module of the Qt GUI Toolkit.
 **
@@ -50,7 +50,14 @@
 
 #ifdef QT_THREAD_SUPPORT
 
+#ifndef QT_H
 #include "qmutex.h"
+#include "qwindowdefs.h"
+#endif // QT_H
+
+#ifdef Q_OS_UNIX
+#include <pthread.h>
+#endif
 
 class QThreadInstance {
 public:
@@ -78,7 +85,7 @@ public:
 #endif // Q_OS_UNIX
 
 #ifdef Q_OS_WIN32
-    HANDLE handle;
+    Qt::HANDLE handle;
     unsigned int thread_id;
     int waiters;
 
