@@ -1,11 +1,11 @@
 /****************************************************************************
-** $Id: qt/qvaluelist.h   3.3.1   edited May 27 2003 $
+** $Id: qt/qvaluelist.h   3.3.6   edited Aug 31 2005 $
 **
 ** Definition of QValueList class
 **
 ** Created : 990406
 **
-** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the tools module of the Qt GUI Toolkit.
 **
@@ -351,8 +351,9 @@ Q_INLINE_TEMPLATES uint QValueListPrivate<T>::contains( const T& x ) const
 }
 
 template <class T>
-Q_INLINE_TEMPLATES uint QValueListPrivate<T>::remove( const T& x )
+Q_INLINE_TEMPLATES uint QValueListPrivate<T>::remove( const T& _x )
 {
+    const T x = _x;
     uint result = 0;
     Iterator first = Iterator( node->next );
     Iterator last = Iterator( node );
@@ -618,7 +619,8 @@ Q_INLINE_TEMPLATES QValueList<T> QValueList<T>::operator+ ( const QValueList<T>&
 template <class T>
 Q_INLINE_TEMPLATES QValueList<T>& QValueList<T>::operator+= ( const QValueList<T>& l )
 {
-    for( const_iterator it = l.begin(); it != l.end(); ++it )
+    QValueList<T> copy = l;
+    for( const_iterator it = copy.begin(); it != copy.end(); ++it )
 	append( *it );
     return *this;
 }
