@@ -1,11 +1,11 @@
 /****************************************************************************
-** $Id: qt/qbuttongroup.cpp   3.3.4   edited Oct 6 13:26 $
+** $Id: qt/qbuttongroup.cpp   3.3.6   edited Aug 31 2005 $
 **
 ** Implementation of QButtonGroup class
 **
 ** Created : 950130
 **
-** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the widgets module of the Qt GUI Toolkit.
 **
@@ -624,9 +624,11 @@ QButton * QButtonGroup::selected() const
 
 /*!
     \property QButtonGroup::selectedId
-    \brief The id of the selected toggle button.
+    \brief the selected toggle button
 
-    If no toggle button is selected, id() returns -1.
+    The toggle button is specified as an ID.
+
+    If no toggle button is selected, this property holds -1.
 
     If setButton() is called on an exclusive group, the button with
     the given id will be set to on and all the others will be set to
