@@ -1,5 +1,5 @@
 /**********************************************************************
-** $Id: qt/qcombobox.cpp   3.3.5   edited Aug 31 12:13 $
+** $Id: qt/qcombobox.cpp   3.3.6   edited Jan 30 11:08 $
 **
 ** Implementation of QComboBox widget class
 **
@@ -347,9 +347,14 @@ public:
     {
 	return QPopupMenu::itemHeight( index );
     }
-
 };
 
+static inline QString escapedComboString(const QString &str)
+{
+    QString stringToReturn = str;
+    return stringToReturn.replace('&', "&&");
+}
+
 class QComboBoxPopupItem : public QCustomMenuItem
 {
     QListBoxItem *li;
@@ -634,7 +639,7 @@ void QComboBox::insertStrList( const QStrList *list, int index )
 	if ( d->usingListBox() )
 	    d->listBox()->insertItem( QString::fromLatin1(tmp), index );
 	else
-	    d->popup()->insertItem( QString::fromLatin1(tmp), index, index );
+	    d->popup()->insertItem( escapedComboString(QString::fromLatin1(tmp)), index, index );
 	if ( index++ == d->current && d->current < count() ) {
 	    if ( d->ed ) {
 		d->ed->setText( text( d->current ) );
@@ -662,7 +667,7 @@ void QComboBox::insertStringList( const QStringList &list, int index )
 	if ( d->usingListBox() )
 	    d->listBox()->insertItem( *it, index );
 	else
-	    d->popup()->insertItem( *it, index, index );
+	    d->popup()->insertItem( escapedComboString(*it), index, index );
 	if ( index++ == d->current && d->current < count() ) {
 	    if ( d->ed ) {
 		d->ed->setText( text( d->current ) );
@@ -709,7 +714,7 @@ void QComboBox::insertStrList( const char **strings, int numStrings, int index)
 	if ( d->usingListBox() )
 	    d->listBox()->insertItem( QString::fromLatin1(strings[i]), index );
 	else
-	    d->popup()->insertItem( QString::fromLatin1(strings[i]), index, index );
+	    d->popup()->insertItem( escapedComboString(QString::fromLatin1(strings[i])), index, index );
 	i++;
 	if ( index++ == d->current && d->current < count()  ) {
 	    if ( d->ed ) {
@@ -738,7 +743,7 @@ void QComboBox::insertItem( const QString &t, int index )
     if ( d->usingListBox() )
 	d->listBox()->insertItem( t, index );
     else
-	d->popup()->insertItem( t, index, index );
+	d->popup()->insertItem( escapedComboString(t), index, index );
     if ( index != cnt )
 	reIndex();
     if ( index == d->current && d->current < count()  ) {
@@ -796,7 +801,7 @@ void QComboBox::insertItem( const QPixmap &pixmap, const QString& text, int inde
     if ( d->usingListBox() )
 	d->listBox()->insertItem( pixmap, text, index );
     else
-	d->popup()->insertItem( pixmap, text, index, index );
+	d->popup()->insertItem( pixmap, escapedComboString(text), index, index );
     if ( index != cnt )
 	reIndex();
     if ( index == d->current && d->current < count()  ) {
@@ -922,10 +927,13 @@ QString QComboBox::text( int index ) const
 {
     if ( !checkIndex( "text", name(), count(), index ) )
 	return QString::null;
-    if ( d->usingListBox() )
+    if ( d->usingListBox() ) {
 	return d->listBox()->text( index );
-    else
-	return d->popup()->text( index );
+    } else {
+        QString retText = d->popup()->text(index);
+        retText.replace("&&", "&");
+	return retText;
+    }
 }
 
 /*!
@@ -1535,12 +1543,12 @@ void QComboBox::popup()
 	    for(unsigned int i = 0; i < d->listBox()->count(); i++) {
 		QListBoxItem *item = d->listBox()->item(i);
 		if(item->rtti() == QListBoxText::RTTI) {
-		    d->popup()->insertItem(item->text(), i, i);
+		    d->popup()->insertItem(escapedComboString(item->text()), i, i);
 		} else if(item->rtti() == QListBoxPixmap::RTTI) {
 		    if(item->pixmap())
-			d->popup()->insertItem(QIconSet(*item->pixmap()), item->text(), i, i);
+			d->popup()->insertItem(QIconSet(*item->pixmap()), escapedComboString(item->text()), i, i);
 		    else
-			d->popup()->insertItem(item->text(), i, i);
+			d->popup()->insertItem(escapedComboString(item->text()), i, i);
 		} else {
 		    d->popup()->insertItem(new QComboBoxPopupItem(item), i, i);
 		}
