@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qdatetimeedit.cpp   3.3.5   edited Aug 31 12:13 $
+** $Id: qt/qdatetimeedit.cpp   3.3.6   edited Jan 10 21:41 $
 **
 ** Implementation of date and time edit classes
 **
@@ -1281,7 +1281,7 @@ void QDateEdit::stepUp()
 	}
     }
     if ( accepted ) {
-	d->changed = TRUE;
+	d->changed = FALSE;
 	emit valueChanged( date() );
     }
     d->ed->repaint( d->ed->rect(), FALSE );
@@ -1314,7 +1314,7 @@ void QDateEdit::stepDown()
 	}
     }
     if ( accepted ) {
-	d->changed = TRUE;
+	d->changed = FALSE;
 	emit valueChanged( date() );
     }
     d->ed->repaint( d->ed->rect(), FALSE );
@@ -1540,7 +1540,7 @@ void QDateEdit::addNumber( int sec, int num )
 	}
     }
     if ( accepted ) {
-	d->changed = TRUE;
+	d->changed = FALSE;
 	emit valueChanged( date() );
     }
     d->overwrite = overwrite;
@@ -2120,7 +2120,7 @@ void QTimeEdit::stepUp()
 	break;
     }
     if ( accepted ) {
-	d->changed = TRUE;
+	d->changed = FALSE;
 	emit valueChanged( time() );
     }
     d->ed->repaint( d->ed->rect(), FALSE );
@@ -2172,7 +2172,7 @@ void QTimeEdit::stepDown()
 	break;
     }
     if ( accepted ) {
-	d->changed = TRUE;
+	d->changed = FALSE;
 	emit valueChanged( time() );
     }
     d->ed->repaint( d->ed->rect(), FALSE );
@@ -2452,7 +2452,7 @@ void QTimeEdit::addNumber( int sec, int num )
     default:
 	break;
     }
-    d->changed = accepted;
+    d->changed = !accepted;
     if ( accepted )
 	emit valueChanged( time() );
     d->overwrite = overwrite;
