@@ -1,5 +1,5 @@
 /**********************************************************************
-** $Id: qt/qgroupbox.cpp   3.3.5   edited Aug 31 12:13 $
+** $Id: qt/qgroupbox.cpp   3.3.6   edited Feb 3 16:07 $
 **
 ** Implementation of QGroupBox widget class
 **
@@ -48,6 +48,7 @@
 #include "qapplication.h"
 #include "qstyle.h"
 #include "qcheckbox.h"
+#include "qbuttongroup.h"
 #if defined(QT_ACCESSIBILITY_SUPPORT)
 #include "qaccessible.h"
 #endif
@@ -837,6 +838,8 @@ void QGroupBox::setCheckable( bool b )
     if ( b ) {
 	if ( !d->checkbox ) {
 	    d->checkbox = new QCheckBox( title(), this, "qt_groupbox_checkbox" );
+            if (QButtonGroup *meAsButtonGroup = ::qt_cast<QButtonGroup*>(this))
+                meAsButtonGroup->remove(d->checkbox);
 	    setChecked( TRUE );
 	    setChildrenEnabled( TRUE );
 	    connect( d->checkbox, SIGNAL( toggled(bool) ),
