@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qmainwindow.cpp   3.3.5   edited Aug 31 12:13 $
+** $Id: qt/qmainwindow.cpp   3.3.6   edited Jan 30 09:46 $
 **
 ** Implementation of QMainWindow class
 **
@@ -287,8 +287,9 @@ class QHideToolTip : public QToolTip
 {
 public:
     QHideToolTip( QWidget *parent ) : QToolTip( parent ) {}
+    ~QHideToolTip() {}
 
-    void maybeTip( const QPoint &pos );
+    virtual void maybeTip( const QPoint &pos );
 };
 #endif
 
