@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qtabbar.cpp   3.3.5   edited Aug 31 12:13 $
+** $Id: qt/qtabbar.cpp   3.3.6   edited Mar 3 19:46 $
 **
 ** Implementation of QTab and QTabBar classes
 **
@@ -49,6 +49,10 @@
 #include "qaccessible.h"
 #endif
 
+#ifdef Q_WS_MACX
+#include <qmacstyle_mac.h>
+#endif
+
 
 /*!
     \class QTab qtabbar.h
@@ -578,6 +582,8 @@ void QTabBar::paint( QPainter * p, QTab * t, bool selected ) const
 
     if (isEnabled() && t->isEnabled())
 	flags |= QStyle::Style_Enabled;
+    if (topLevelWidget() == qApp->activeWindow())
+	flags |= QStyle::Style_Active;
     if ( selected )
 	flags |= QStyle::Style_Selected;
     else if(t == d->pressed)
@@ -603,7 +609,12 @@ void QTabBar::paint( QPainter * p, QTab * t, bool selected ) const
     fw += t->label.contains("&&") * fm.width('&');
     int w = iw + fw + 4;
     int h = QMAX(fm.height() + 4, ih );
-    paintLabel( p, QRect( r.left() + (r.width()-w)/2 - 3,
+    int offset = 3;
+#ifdef Q_WS_MAC
+    if (::qt_cast<QMacStyle *>(&style()))
+        offset = 0;
+#endif
+    paintLabel( p, QRect( r.left() + (r.width()-w)/2 - offset,
 			  r.top() + (r.height()-h)/2,
 			  w, h ), t, t->id == keyboardFocusTab() );
 }
@@ -862,8 +873,12 @@ void QTabBar::setCurrentTab( QTab * tab )
 	if ( tab->r.intersects( r ) ) {
 	    repaint( r.unite( tab->r ), FALSE );
 	} else {
+#ifdef Q_WS_MACX
+            update();
+#else
 	    repaint( r, FALSE );
 	    repaint( tab->r, FALSE );
+#endif
 	}
 	makeVisible( tab );
 	emit selected( tab->id );
@@ -1090,7 +1105,7 @@ void QTabBar::layoutTabs()
 
 	h += vframe;
 	t->r = QRect(QPoint(x, 0), style().sizeFromContents(QStyle::CT_TabBarTab, this,
-   	             QSize( QMAX( lw + hframe + iw, QApplication::globalStrut().width() ), h ),
+	             QSize( QMAX( lw + hframe + iw, QApplication::globalStrut().width() ), h ),
 		     QStyleOption(t) ));
 	x += t->r.width() - overlap;
 	r = r.unite( t->r );
