@@ -1,11 +1,11 @@
 /****************************************************************************
-** $Id: qt/qtabwidget.h   3.1.2   edited Nov 7 16:55 $
+** $Id: qt/qtabwidget.h   3.3.6   edited Aug 31 2005 $
 **
 ** Definition of QTabWidget class
 **
 ** Created : 990318
 **
-** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the widgets module of the Qt GUI Toolkit.
 **
@@ -67,7 +67,7 @@ public:
     QTabWidget( QWidget *parent = 0, const char *name = 0, WFlags f = 0 );
     ~QTabWidget();
 
-    virtual void addTab( QWidget *, const QString & );
+    virtual void addTab( QWidget *, const QString & ); // ### make these inline in 4.0
     virtual void addTab( QWidget *child, const QIconSet& iconset,
 			 const QString &label );
     virtual void addTab( QWidget *, QTab* );
@@ -84,6 +84,9 @@ public:
     bool isTabEnabled(  QWidget * ) const;
     void setTabEnabled( QWidget *, bool );
 
+    void setCornerWidget( QWidget * w, Qt::Corner corner = Qt::TopRight );
+    QWidget * cornerWidget( Qt::Corner corner = Qt::TopRight ) const;
+
     QString tabLabel( QWidget * ) const;
     void setTabLabel( QWidget *p, const QString &l );
 
@@ -137,12 +140,11 @@ signals:
 #endif
 
 private slots:
-    void showTab( int i );
+    void showTab( int );
 
 private:
     QTabWidgetData *d;
     void setUpLayout( bool = FALSE );
-
     friend class QTabDialog;
 
 private:	// Disabled copy constructor and operator=
