@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qtoolbar.cpp   3.3.5   edited Aug 31 12:13 $
+** $Id: qt/qtoolbar.cpp   3.3.6   edited Jan 30 10:04 $
 **
 ** Implementation of QToolBar class
 **
@@ -648,7 +648,7 @@ void QToolBar::createPopup()
 	        QString s = b->textLabel();
 	        if ( s.isEmpty() )
 		    s = b->text();
-	        if ( b->popup() && b->popupDelay() == 0 )
+	        if ( b->popup() && b->popupDelay() <= 0 )
 		    id = d->extensionPopup->insertItem( b->iconSet(), s, b->popup() );
 		else
 		    id = d->extensionPopup->insertItem( b->iconSet(), s, b, SLOT( emulateClick() ) ) ;
