@@ -1,5 +1,5 @@
 /**********************************************************************
-** Copyright (C) 2000-2003 Trolltech AS.  All rights reserved.
+** Copyright (C) 2000-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the Qt Assistant.
 **
@@ -230,7 +230,7 @@ void Config::loadDefaultProfile()
 
 void Config::saveProfile( Profile *profile )
 {
-    if (profil->profileType() == Profile::UserProfile)
+    if (profil && profil->profileType() == Profile::UserProfile)
 	return;
     QSettings settings;
     settings.insertSearchPath( QSettings::Windows, "/Trolltech" );
