@@ -1,5 +1,5 @@
 /**********************************************************************
-** Copyright (C) 2000-2002 Trolltech AS.  All rights reserved.
+** Copyright (C) 2000-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of Qt Designer.
 **
@@ -1733,7 +1733,7 @@ void PopulateTableCommand::execute()
 {
 #ifndef QT_NO_TABLE
     QMap<QString, QString> columnFields;
-    table->setNumCols( newColumns.count() );
+    table->setNumCols( (int)newColumns.count() );
     int i = 0;
     for ( QValueList<Column>::Iterator cit = newColumns.begin(); cit != newColumns.end(); ++cit, ++i ) {
 	table->horizontalHeader()->setLabel( i, (*cit).pix, (*cit).text );
@@ -1741,7 +1741,7 @@ void PopulateTableCommand::execute()
 	    columnFields.insert( (*cit).text, (*cit).field );
     }
     MetaDataBase::setColumnFields( table, columnFields );
-    table->setNumRows( newRows.count() );
+    table->setNumRows( (int)newRows.count() );
     i = 0;
     for ( QValueList<Row>::Iterator rit = newRows.begin(); rit != newRows.end(); ++rit, ++i )
 	table->verticalHeader()->setLabel( i, (*rit).pix, (*rit).text );
@@ -1752,7 +1752,7 @@ void PopulateTableCommand::unexecute()
 {
 #ifndef QT_NO_TABLE
     QMap<QString, QString> columnFields;
-    table->setNumCols( oldColumns.count() );
+    table->setNumCols( (int)oldColumns.count() );
     int i = 0;
     for ( QValueList<Column>::Iterator cit = oldColumns.begin(); cit != oldColumns.end(); ++cit, ++i ) {
 	table->horizontalHeader()->setLabel( i, (*cit).pix, (*cit).text );
@@ -1760,7 +1760,7 @@ void PopulateTableCommand::unexecute()
 	    columnFields.insert( (*cit).text, (*cit).field );
     }
     MetaDataBase::setColumnFields( table, columnFields );
-    table->setNumRows( oldRows.count() );
+    table->setNumRows( (int)oldRows.count() );
     i = 0;
     for ( QValueList<Row>::Iterator rit = oldRows.begin(); rit != oldRows.end(); ++rit, ++i )
 	table->verticalHeader()->setLabel( i, (*rit).pix, (*rit).text );
