@@ -1,5 +1,5 @@
 /**********************************************************************
-** Copyright (C) 2000-2002 Trolltech AS.  All rights reserved.
+** Copyright (C) 2000-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of Qt Designer.
 **
@@ -1212,7 +1212,7 @@ public:
     void execute();
     void unexecute();
     Type type() const { return RenameMenu; }
-    static QString makeLegal( QString str );
+    static QString makeLegal( const QString &str );
 private:
     MenuBarEditor *bar;
     MenuBarEditorItem *item;
