@@ -63,7 +63,7 @@ static QString make_func_pretty( const QString &s )
 FormFile::FormFile( const QString &fn, bool temp, Project *p, const char *name )
     : filename( fn ), fileNameTemp( temp ), pro( p ), fw( 0 ), ed( 0 ),
       timeStamp( 0, fn + codeExtension() ), codeEdited( FALSE ), pkg( FALSE ),
-      cm( FALSE ), codeFileStat( None )
+      cm( FALSE ), codeFileStat( None ), timeStampUi(0, fn)
 {
     MetaDataBase::addEntry( this );
     fake = qstrcmp( name, "qt_fakewindow" ) == 0;
@@ -72,6 +72,7 @@ FormFile::FormFile( const QString &fn, bool temp, Project *p, const char *name )
     loadCode();
     if ( !temp )
 	checkFileName( FALSE );
+    timeStampUi.update();
 }
 
 FormFile::~FormFile()
@@ -113,6 +114,7 @@ void FormFile::setFileName( const QString &fn )
     }
     filename = fn;
     timeStamp.setFileName( filename + codeExtension() );
+    timeStampUi.setFileName( filename );
     cod = "";
     loadCode();
 }
@@ -163,6 +165,8 @@ bool FormFile::save( bool withMsgBox, bool ignoreModified )
 	return TRUE;
     if ( ed )
 	ed->save();
+    if (!shouldOverwriteUi())
+        return TRUE;
 
     if ( formWindow() && isModified( WFormWindow ) ) {
 	if ( withMsgBox ) {
@@ -236,10 +240,21 @@ bool FormFile::save( bool withMsgBox, bool ignoreModified )
 	    return FALSE;
     }
     timeStamp.update();
+    timeStampUi.update();
     setModified( FALSE );
     return TRUE;
 }
 
+bool FormFile::shouldOverwriteUi() const
+{
+    if (timeStampUi.isUpToDate())
+	return TRUE;
+    return (QMessageBox::information(MainWindow::self, tr( "Qt Designer" ),
+                                     tr("File '%1' has been changed outside Qt Designer.\n"
+                                        "Do you want to overwrite it?" ).arg(timeStampUi.fileName()),
+                                     tr("&Yes"), tr("&No")) == 0);
+}
+
 bool FormFile::saveAs( bool ignoreModified )
 {
     QString f = pro->makeAbsolute( fileName() );
