@@ -1,5 +1,5 @@
 /**********************************************************************
-** Copyright (C) 2000-2001 Trolltech AS.  All rights reserved.
+** Copyright (C) 2000-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of Qt Designer.
 **
@@ -8,10 +8,16 @@
 ** Foundation and appearing in the file LICENSE.GPL included in the
 ** packaging of this file.
 **
+** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
+** licenses may use this file in accordance with the Qt Commercial License
+** Agreement provided with the Software.
+**
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 **
 ** See http://www.trolltech.com/gpl/ for GPL licensing information.
+** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
+**   information about Qt Commercial License Agreements.
 **
 ** Contact info@trolltech.com if any conditions of this licensing are
 ** not clear to you.
@@ -180,14 +186,15 @@ void SourceFileItem::insert( Project *pro )
 
 void SourceFileItem::setProject( Project *pro )
 {
+    QIconView *iv = iconView();
     bool v = lang == pro->language();
-    if ( v == visible )
+    if ( !iv || v == visible )
 	return;
     visible = v;
     if ( !visible )
-	iconView()->takeItem( this );
+	iv->takeItem( this );
     else
-	iconView()->insertItem( this );
+	iv->insertItem( this );
 }
 
 
@@ -210,21 +217,26 @@ void SourceTemplateItem::insert( Project *pro )
 	f = new SourceFile( src.filename, FALSE, pro );
     else
 	f = new SourceFile( SourceFile::createUnnamedFileName( src.extension ), TRUE, pro );
-    f->setText( src.code );
-    MainWindow::self->editSource( f );
-    f->setModified( TRUE );
+    if ( f->isAccepted()) {
+	f->setText( src.code );
+	MainWindow::self->editSource( f );
+	f->setModified( TRUE );
+    } else {
+	delete f;
+    }
 }
 
 void SourceTemplateItem::setProject( Project *pro )
 {
+    QIconView *iv = iconView();
     bool v = !pro->isDummy() && lang == pro->language();
-    if ( v == visible )
+    if ( !iv || v == visible )
 	return;
     visible = v;
     if ( !visible )
-	iconView()->takeItem( this );
+	iv->takeItem( this );
     else
-	iconView()->insertItem( this );
+	iv->insertItem( this );
 }
 
 void NewForm::insertTemplates( QIconView *tView,
@@ -237,7 +249,7 @@ void NewForm::insertTemplates( QIconView *tView,
 	    ProjectItem *pi = new ProjectItem( tView, *it + " " + tr( "Project" ) );
 	    allItems.append( pi );
 	    pi->setLanguage( *it );
-	    pi->setPixmap( QPixmap::fromMimeSource( "project.png" ) );
+	    pi->setPixmap( QPixmap::fromMimeSource( "designer_project.png" ) );
 	    pi->setDragEnabled( FALSE );
 	}
     }
@@ -245,24 +257,24 @@ void NewForm::insertTemplates( QIconView *tView,
     FormItem *fi = new FormItem( tView,tr( "Dialog" ) );
     allItems.append( fi );
     fi->setFormType( FormItem::Dialog );
-    fi->setPixmap( QPixmap::fromMimeSource( "newform.png" ) );
+    fi->setPixmap( QPixmap::fromMimeSource( "designer_newform.png" ) );
     fi->setDragEnabled( FALSE );
     cur = fi;
     if ( !MainWindow::self->singleProjectMode() ) {
 	fi = new FormItem( tView,tr( "Wizard" ) );
 	allItems.append( fi );
 	fi->setFormType( FormItem::Wizard );
-	fi->setPixmap( QPixmap::fromMimeSource( "newform.png" ) );
+	fi->setPixmap( QPixmap::fromMimeSource( "designer_newform.png" ) );
 	fi->setDragEnabled( FALSE );
 	fi = new FormItem( tView, tr( "Widget" ) );
 	allItems.append( fi );
 	fi->setFormType( FormItem::Widget );
-	fi->setPixmap( QPixmap::fromMimeSource( "newform.png" ) );
+	fi->setPixmap( QPixmap::fromMimeSource( "designer_newform.png" ) );
 	fi->setDragEnabled( FALSE );
 	fi = new FormItem( tView, tr( "Main Window" ) );
 	allItems.append( fi );
 	fi->setFormType( FormItem::MainWindow );
-	fi->setPixmap( QPixmap::fromMimeSource( "newform.png" ) );
+	fi->setPixmap( QPixmap::fromMimeSource( "designer_newform.png" ) );
 	fi->setDragEnabled( FALSE );
 
 	QString templPath = templatePath;
@@ -295,7 +307,7 @@ void NewForm::insertTemplates( QIconView *tView,
 		    CustomFormItem *ci = new CustomFormItem( tView, name );
 		    allItems.append( ci );
 		    ci->setDragEnabled( FALSE );
-		    ci->setPixmap( QPixmap::fromMimeSource( "newform.png" ) );
+		    ci->setPixmap( QPixmap::fromMimeSource( "designer_newform.png" ) );
 		    ci->setTemplateFile( fi->absFilePath() );
 		}
 	    }
@@ -313,7 +325,7 @@ void NewForm::insertTemplates( QIconView *tView,
 		allItems.append( si );
 		si->setExtension( eit.key() );
 		si->setLanguage( *it );
-		si->setPixmap( QPixmap::fromMimeSource( "filenew.png" ) );
+		si->setPixmap( QPixmap::fromMimeSource( "designer_filenew.png" ) );
 		si->setDragEnabled( FALSE );
 	    }
 	    iface->release();
@@ -330,7 +342,7 @@ void NewForm::insertTemplates( QIconView *tView,
 	    allItems.append( si );
 	    si->setTemplate( *sit );
 	    si->setLanguage( siface->language( *sit ) );
-	    si->setPixmap( QPixmap::fromMimeSource( "filenew.png" ) );
+	    si->setPixmap( QPixmap::fromMimeSource( "designer_filenew.png" ) );
 	    si->setDragEnabled( FALSE );
 	    siface->release();
 	}
