@@ -600,7 +600,7 @@ bool EditorCompletion::doArgumentHint( bool useIndex )
     int w = 0;
     int num = 0;
     if ( !functionLabel->isVisible() )
-	functionLabel->setNumFunctions( argl.count() );
+	functionLabel->setNumFunctions( (int)argl.count() );
     for ( QValueList<QStringList>::Iterator vit = argl.begin(); vit != argl.end(); ++vit, ++num ) {
 	QStringList args = *vit;
 	int argNum = 0;
