@@ -1,5 +1,5 @@
  /**********************************************************************
-** Copyright (C) 2000 Trolltech AS.  All rights reserved.
+** Copyright (C) 2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of Qt Designer.
 **
@@ -8,10 +8,16 @@
 ** Foundation and appearing in the file LICENSE.GPL included in the
 ** packaging of this file.
 **
+** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
+** licenses may use this file in accordance with the Qt Commercial License
+** Agreement provided with the Software.
+**
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 **
 ** See http://www.trolltech.com/gpl/ for GPL licensing information.
+** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
+**   information about Qt Commercial License Agreements.
 **
 ** Contact info@trolltech.com if any conditions of this licensing are
 ** not clear to you.
@@ -40,6 +46,7 @@
 #ifndef QT_NO_SQL
 #include <qdatatable.h>
 #include <qdatabrowser.h>
+#include <qdataview.h>
 #include <qsqleditorfactory.h>
 #include <qsqlindex.h>
 #include <qsqlcursor.h>
@@ -55,18 +62,18 @@ SqlFormWizard::SqlFormWizard( QUnknownInterface *aIface, QWidget *w,
     setFinishEnabled( finishPage, TRUE );
 
     /* set mode of operation */
-    if ( widget->inherits( "QDataTable" ) ) {
+    if ( ::qt_cast<QDataTable*>(widget) ) {
 	setCaption( "Data Table Wizard" );
 	mode = Table;
 	setAppropriate( navigPage, FALSE );
 	setAppropriate( layoutPage, FALSE );
 	checkBoxAutoEdit->setChecked( FALSE );
-    } else if ( widget->inherits( "QDataBrowser" ) ) {
+    } else if ( ::qt_cast<QDataBrowser*>(widget) ) {
 	setCaption( "Data Browser Wizard" );
 	setAppropriate( tablePropertiesPage, FALSE );
 	mode = Browser;
 	checkBoxAutoEdit->setChecked( TRUE );
-    } else if ( widget->inherits( "QDataView" ) ) {
+    } else if ( ::qt_cast<QDataView*>(widget) ) {
 	setCaption( "Data View Wizard" );
 	setAppropriate( tablePropertiesPage, FALSE );
 	setAppropriate( navigPage, FALSE );
@@ -77,14 +84,23 @@ SqlFormWizard::SqlFormWizard( QUnknownInterface *aIface, QWidget *w,
 	mode = View;
     }
 
+    connect( nextButton(), SIGNAL(clicked()), SLOT(nextPageClicked()) );
     setupPage1();
 }
 
+
 SqlFormWizard::~SqlFormWizard()
 {
     appIface->release();
 }
 
+void SqlFormWizard::nextPageClicked()
+{
+    if ( currentPage() == populatePage ) {
+	autoPopulate( TRUE );
+    }
+}
+
 void SqlFormWizard::connectionSelected( const QString &c )
 {
     if ( !appIface )
@@ -106,7 +122,6 @@ void SqlFormWizard::connectionSelected( const QString &c )
 void SqlFormWizard::tableSelected( const QString & )
 {
     if ( listBoxTable->currentItem() >= 0 ) {
-	autoPopulate( TRUE );
 	setNextEnabled( databasePage, TRUE );
     } else {
 	setNextEnabled( databasePage, FALSE );
@@ -130,6 +145,7 @@ void SqlFormWizard::autoPopulate( bool populate )
 		 listBoxConnection->currentText() == "(default)" ) ) {
 		QStringList lst = *d->fields().find( listBoxTable->currentText() );
 		// remove primary index fields, if any
+		listBoxSortField->insertStringList( lst );
 		d->open( FALSE );
 #ifndef QT_NO_SQL
 		QSqlCursor tab( listBoxTable->currentText(), TRUE, d->connection() );
@@ -141,7 +157,6 @@ void SqlFormWizard::autoPopulate( bool populate )
 #endif
 		d->close();
 		listBoxSelectedField->insertStringList( lst );
-		listBoxSortField->insertStringList( lst );
 	    }
 	}
     }
@@ -428,7 +443,7 @@ void SqlFormWizard::accept()
 		((QLineEdit*)editor)->setAlignment( Qt::AlignRight );
 		formWindow->setPropertyChanged( editor, "alignment", TRUE );
 	    }
-	    if ( editor->inherits( "QSpinBox" ) ) {
+	    if ( ::qt_cast<QSpinBox*>(editor) ) {
 		( (QSpinBox*)editor )->setMaxValue( INT_MAX );
 		formWindow->setPropertyChanged( editor, "maxValue", TRUE );
 	    }
