@@ -1,5 +1,5 @@
 /**********************************************************************
-** Copyright (C) 1992-2002 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of Qt/Embedded virtual framebuffer.
 **
@@ -57,6 +57,7 @@ QVFb::QVFb( int display_id, int w, int h, int d, const QString &skin, QWidget *p
     view = 0;
     init( display_id, w, h, d, skin );
     createMenu( menuBar() );
+    adjustSize();
 }
 
 QVFb::~QVFb()
@@ -100,7 +101,7 @@ void QVFb::init( int display_id, int w, int h, int d, const QString &skin_name )
 	view->setMargin( 0 );
 	view->setFrameStyle( QFrame::NoFrame );
 	setCentralWidget( view );
-	resize(w,menuBar()->height()+h+2);
+	resize( sizeHint() );
 	view->show();
     }
 
@@ -229,7 +230,7 @@ void QVFb::about()
 	"<p><b><font size=+2>Qt/Embedded Virtual " + platform + " Framebuffer</font></b></p>"
 	"<p></p>"
 	"<p>Version 1.0</p>"
-	"<p>Copyright (C) 2001-2002 Trolltech AS. All rights reserved.</p>"
+	"<p>Copyright (C) 2001-2005 Trolltech AS. All rights reserved.</p>"
 	"<p></p>"
 	"<p>This program is licensed to you under the terms of the GNU General "
 	"Public License Version 2 as published by the Free Software Foundation. This "
@@ -373,9 +374,3 @@ void QVFb::updateGammaLabels()
     config->glabel->setText(QString::number(view->gammaGreen(),'g',2));
     config->blabel->setText(QString::number(view->gammaBlue(),'g',2));
 }
-
-QSize QVFb::sizeHint() const
-{
-    return QSize((int)(view->displayWidth()*view->zoom()),
-	    (int)(menuBar()->height()+view->displayHeight()*view->zoom()));
-}
